@@ -329,12 +329,11 @@ func (o *initEnvOpts) validateCustomizedResources() error {
 		return fmt.Errorf("cannot import or configure vpc if --%s is set", defaultConfigFlag)
 	}
 	if o.importVPC.isSet() {
-		// We allow 0 or 2+ public subnets.
+		// Allow passing in VPC without subnets, but error out early for too few subnets-- we won't prompt the user to select more of one type if they pass in any.
 		if len(o.importVPC.PublicSubnetIDs) == 1 {
-			return fmt.Errorf("at least two public subnets must be imported to enable Load Balancing")
+			return errors.New("at least two public subnets must be imported to enable Load Balancing")
 		}
-		// We require 2+ private subnets.
-		if len(o.importVPC.PrivateSubnetIDs) < 2 {
+		if len(o.importVPC.PrivateSubnetIDs) == 1 {
 			return fmt.Errorf("at least two private subnets must be imported")
 		}
 	}
@@ -468,10 +467,15 @@ https://aws.amazon.com/premiumsupport/knowledge-center/ecs-pull-container-api-er
 		return fmt.Errorf("VPC %s has no DNS support enabled", o.importVPC.ID)
 	}
 	if o.importVPC.PublicSubnetIDs == nil {
-		publicSubnets, err := o.selVPC.PublicSubnets(envInitPublicSubnetsSelectPrompt, "", o.importVPC.ID)
+		publicSubnets, err := o.selVPC.Subnets(selector.SubnetsInput{
+			Msg:      envInitPublicSubnetsSelectPrompt,
+			Help:     "",
+			VPCID:    o.importVPC.ID,
+			IsPublic: true,
+		})
 		if err != nil {
-			if err == selector.ErrSubnetsNotFound {
-				log.Warningf(`No existing public subnets were found in VPC %s.
+			if errors.Is(err, selector.ErrSubnetsNotFound) {
+				log.Warningf(`No existing subnets were found in VPC %s.
 If you proceed without at least two public subnets, you will not be able to deploy Load Balanced Web Services in this environment.
 `, o.importVPC.ID)
 			} else {
@@ -484,16 +488,21 @@ If you proceed without at least two public subnets, you will not be able to depl
 		o.importVPC.PublicSubnetIDs = publicSubnets
 	}
 	if o.importVPC.PrivateSubnetIDs == nil {
-		privateSubnets, err := o.selVPC.PrivateSubnets(envInitPrivateSubnetsSelectPrompt, "", o.importVPC.ID)
+		privateSubnets, err := o.selVPC.Subnets(selector.SubnetsInput{
+			Msg:      envInitPrivateSubnetsSelectPrompt,
+			Help:     "",
+			VPCID:    o.importVPC.ID,
+			IsPublic: false,
+		})
 		if err != nil {
 			if err == selector.ErrSubnetsNotFound {
-				log.Errorf(`No existing private subnets were found in VPC %s. You can either:
+				log.Errorf(`No existing subnets were found in VPC %s. You can either:
 - Create new private subnets and then import them.
 - Use the default Copilot environment configuration.`, o.importVPC.ID)
 			}
 			return fmt.Errorf("select private subnets: %w", err)
 		}
-		if len(privateSubnets) == 1 {
+		if len(privateSubnets) < 2 {
 			return errors.New("select private subnets: at least two private subnets must be selected")
 		}
 		o.importVPC.PrivateSubnetIDs = privateSubnets
@@ -685,7 +694,7 @@ func buildEnvInitCmd() *cobra.Command {
 
   Creates an environment with imported VPC resources.
   /code $ copilot env init --import-vpc-id vpc-099c32d2b98cdcf47 \
-  /code --import-public-subnets subnet-013e8b691862966cf,subnet -014661ebb7ab8681a \
+  /code --import-public-subnets subnet-013e8b691862966cf,subnet-014661ebb7ab8681a \
   /code --import-private-subnets subnet-055fafef48fb3c547,subnet-00c9e76f288363e7f
 
   Creates an environment with overridden CIDRs.
