@@ -455,7 +455,9 @@ func (o *deploySvcOpts) manifest() (interface{}, error) {
 	if err != nil {
 		return nil, fmt.Errorf("apply environment %s override: %s", o.envName, err)
 	}
-
+	if err := mft.Validate(); err != nil {
+		return nil, fmt.Errorf("validate manifest against environment %s: %s", o.envName, err)
+	}
 	o.appliedManifest = envMft // cache the results.
 	return envMft, nil
 }
@@ -657,8 +659,8 @@ func (o *deploySvcOpts) forceDeploy() error {
 	return nil
 }
 
-func validateLBSvcAliasAndAppVersion(svcName string, aliases *manifest.Alias, app *config.Application, envName string, appVersionGetter versionGetter) error {
-	if aliases == nil {
+func validateLBSvcAliasAndAppVersion(svcName string, aliases manifest.Alias, app *config.Application, envName string, appVersionGetter versionGetter) error {
+	if aliases.IsEmpty() {
 		return nil
 	}
 	aliasList, err := aliases.ToStringSlice()
@@ -899,11 +901,11 @@ func (o *deploySvcOpts) buildWorkerQueueNames() string {
 	sb := new(strings.Builder)
 	first := true
 	for _, subscription := range o.subscriptions {
-		if subscription.Queue == nil {
+		if subscription.Queue.IsEmpty() {
 			continue
 		}
-		topicSvc := template.StripNonAlphaNumFunc(subscription.Service)
-		topicName := template.StripNonAlphaNumFunc(subscription.Name)
+		topicSvc := template.StripNonAlphaNumFunc(aws.StringValue(subscription.Service))
+		topicName := template.StripNonAlphaNumFunc(aws.StringValue(subscription.Name))
 		subName := fmt.Sprintf("%s%sEventsQueue", topicSvc, strings.Title(topicName))
 		if first {
 			sb.WriteString(subName)
