@@ -220,6 +220,7 @@ image:
   build:
     dockerfile: path/to/Dockerfile
     context: path
+  port: 80
 `)
 	mockManifestWithBadPlatform := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
@@ -228,6 +229,7 @@ image:
   build:
     dockerfile: path/to/Dockerfile
     context: path
+  port: 80
 `)
 	mockManifestWithGoodPlatform := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
@@ -236,22 +238,26 @@ image:
   build:
     dockerfile: path/to/Dockerfile
     context: path
+  port: 80
 `)
 	mockMftNoBuild := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
 image:
   location: foo/bar
+  port: 80
 `)
 	mockMftBuildString := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
 image:
   build: path/to/Dockerfile
+  port: 80
 `)
 	mockMftNoContext := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
 image:
   build:
-    dockerfile: path/to/Dockerfile`)
+    dockerfile: path/to/Dockerfile
+  port: 80`)
 
 	tests := map[string]struct {
 		inputSvc   string
@@ -563,7 +569,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 		mockAddonsURL = "mockAddonsURL"
 	)
 	tests := map[string]struct {
-		inAliases      *manifest.Alias
+		inAliases      manifest.Alias
 		inApp          *config.Application
 		inEnvironment  *config.Environment
 		inBuildRequire bool
@@ -620,7 +626,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			wantErr: fmt.Errorf("ECR repository not found for service mockSvc in region us-west-2 and account 1234567890"),
 		},
 		"fail to get app version": {
-			inAliases: &manifest.Alias{String: aws.String("mockAlias")},
+			inAliases: manifest.Alias{String: aws.String("mockAlias")},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
@@ -637,7 +643,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			wantErr: fmt.Errorf("get version for app %s: %w", mockAppName, mockError),
 		},
 		"fail to enable https alias because of incompatible app version": {
-			inAliases: &manifest.Alias{String: aws.String("mockAlias")},
+			inAliases: manifest.Alias{String: aws.String("mockAlias")},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
@@ -654,7 +660,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			wantErr: fmt.Errorf("alias is not compatible with application versions below %s", deploy.AliasLeastAppTemplateVersion),
 		},
 		"fail to enable https alias because of invalid alias": {
-			inAliases: &manifest.Alias{String: aws.String("v1.v2.mockDomain")},
+			inAliases: manifest.Alias{String: aws.String("v1.v2.mockDomain")},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
@@ -750,7 +756,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			wantErr: fmt.Errorf("force an update for service mockSvc: max retries 0 exceeded"),
 		},
 		"success": {
-			inAliases: &manifest.Alias{
+			inAliases: manifest.Alias{
 				StringSlice: []string{
 					"v1.mockDomain",
 					"mockDomain",
@@ -830,6 +836,14 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 							Name: aws.String(mockSvcName),
 						},
 						LoadBalancedWebServiceConfig: manifest.LoadBalancedWebServiceConfig{
+							ImageConfig: manifest.ImageWithPortAndHealthcheck{
+								ImageWithPort: manifest.ImageWithPort{
+									Image: manifest.Image{
+										Build: manifest.BuildArgsOrString{BuildString: aws.String("/Dockerfile")},
+									},
+									Port: aws.Uint16(80),
+								},
+							},
 							RoutingRule: manifest.RoutingRule{
 								Alias: tc.inAliases,
 							},
@@ -1106,6 +1120,12 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 							Name: aws.String(mockSvcName),
 						},
 						RequestDrivenWebServiceConfig: manifest.RequestDrivenWebServiceConfig{
+							ImageConfig: manifest.ImageWithPort{
+								Image: manifest.Image{
+									Build: manifest.BuildArgsOrString{BuildString: aws.String("/Dockerfile")},
+								},
+								Port: aws.Uint16(80),
+							},
 							RequestDrivenWebServiceHttpConfig: manifest.RequestDrivenWebServiceHttpConfig{
 								Alias: aws.String(tc.inAlias),
 							},
@@ -1249,7 +1269,13 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 						Workload: manifest.Workload{
 							Name: aws.String(mockSvcName),
 						},
-						WorkerServiceConfig: manifest.WorkerServiceConfig{},
+						WorkerServiceConfig: manifest.WorkerServiceConfig{
+							ImageConfig: manifest.ImageWithHealthcheck{
+								Image: manifest.Image{
+									Build: manifest.BuildArgsOrString{BuildString: aws.String("/Dockerfile")},
+								},
+							},
+						},
 					}, nil
 				},
 			}
