@@ -8,6 +8,9 @@ import (
 	"fmt"
 	"strconv"
 
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
+
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
@@ -167,7 +170,7 @@ func newInitSvcOpts(vars initSvcVars) (*initSvcOpts, error) {
 		if opts.df != nil {
 			return opts.df
 		}
-		opts.df = exec.NewDockerfile(opts.fs, opts.dockerfilePath)
+		opts.df = dockerfile.New(opts.fs, opts.dockerfilePath)
 		return opts.df
 	}
 	return opts, nil
@@ -245,12 +248,12 @@ func (o *initSvcOpts) Ask() error {
 // Execute writes the service's manifest file and stores the service in SSM.
 func (o *initSvcOpts) Execute() error {
 	// Check for a valid healthcheck and add it to the opts.
-	var hc *manifest.ContainerHealthCheck
+	var hc manifest.ContainerHealthCheck
 	var err error
 	if o.dockerfilePath != "" {
 		hc, err = parseHealthCheck(o.dockerfile(o.dockerfilePath))
 		if err != nil {
-			return fmt.Errorf("parse dockerfile %s: %w", o.dockerfilePath, err)
+			log.Warningf("Cannot parse the HEALTHCHECK instruction from the Dockerfile: %v\n", err)
 		}
 	}
 
@@ -259,11 +262,14 @@ func (o *initSvcOpts) Execute() error {
 		return fmt.Errorf("get/redirect docker engine platform: %w", err)
 	}
 	o.platform = platform
+	var platformStrPtr *manifest.PlatformString
 	if o.platform != nil {
-		log.Warningf(`Your architecture type is currently unsupported. Setting platform %s instead.\n`, dockerengine.DockerBuildPlatform(dockerengine.LinuxOS, dockerengine.Amd64Arch))
+		log.Warningf("Your architecture type is currently unsupported. Setting platform %s instead.\n", dockerengine.DockerBuildPlatform(dockerengine.LinuxOS, dockerengine.Amd64Arch))
 		if o.wkldType != manifest.RequestDrivenWebServiceType {
 			log.Warning("See 'platform' field in your manifest.\n")
 		}
+		val := manifest.PlatformString(*o.platform)
+		platformStrPtr = &val
 	}
 
 	manifestPath, err := o.init.Service(&initialize.ServiceProps{
@@ -273,8 +279,10 @@ func (o *initSvcOpts) Execute() error {
 			Type:           o.wkldType,
 			DockerfilePath: o.dockerfilePath,
 			Image:          o.image,
-			Platform:       o.platform,
-			Topics:         o.topics,
+			Platform: manifest.PlatformArgsOrString{
+				PlatformString: platformStrPtr,
+			},
+			Topics: o.topics,
 		},
 		Port:        o.port,
 		HealthCheck: hc,
@@ -398,7 +406,7 @@ func (o *initSvcOpts) askSvcPort() (err error) {
 		return nil
 	}
 
-	var ports []uint16
+	var ports []dockerfile.Port
 	if o.dockerfilePath != "" && o.image == "" {
 		// Check for exposed ports.
 		ports, err = o.dockerfile(o.dockerfilePath).GetExposedPorts()
@@ -414,10 +422,10 @@ func (o *initSvcOpts) askSvcPort() (err error) {
 		case 0:
 			// There were no ports detected, keep the default port prompt.
 		case 1:
-			o.port = ports[0]
+			o.port = ports[0].Port
 			return nil
 		default:
-			defaultPort = strconv.Itoa(int(ports[0]))
+			defaultPort = strconv.Itoa(int(ports[0].Port))
 		}
 	}
 	// Skip asking if it is a backend or worker service.
@@ -477,8 +485,8 @@ func (o *initSvcOpts) askSvcPublishers() (err error) {
 	subscriptions := make([]manifest.TopicSubscription, 0, len(topics))
 	for _, t := range topics {
 		subscriptions = append(subscriptions, manifest.TopicSubscription{
-			Name:    t.Name(),
-			Service: t.Workload(),
+			Name:    aws.String(t.Name()),
+			Service: aws.String(t.Workload()),
 		})
 	}
 	o.topics = subscriptions
@@ -493,20 +501,20 @@ func parseSerializedSubscription(input string) (manifest.TopicSubscription, erro
 		return manifest.TopicSubscription{}, fmt.Errorf("parse subscription from key: %s", input)
 	}
 	return manifest.TopicSubscription{
-		Name:    attrs[2],
-		Service: attrs[1],
+		Name:    aws.String(attrs[2]),
+		Service: aws.String(attrs[1]),
 	}, nil
 }
 
-func parseHealthCheck(df dockerfileParser) (*manifest.ContainerHealthCheck, error) {
+func parseHealthCheck(df dockerfileParser) (manifest.ContainerHealthCheck, error) {
 	hc, err := df.GetHealthCheck()
 	if err != nil {
-		return nil, fmt.Errorf("get healthcheck: %w", err)
+		return manifest.ContainerHealthCheck{}, fmt.Errorf("get healthcheck: %w", err)
 	}
 	if hc == nil {
-		return nil, nil
+		return manifest.ContainerHealthCheck{}, nil
 	}
-	return &manifest.ContainerHealthCheck{
+	return manifest.ContainerHealthCheck{
 		Interval:    &hc.Interval,
 		Timeout:     &hc.Timeout,
 		StartPeriod: &hc.StartPeriod,
