@@ -8,6 +8,9 @@ import (
 	"fmt"
 	"testing"
 
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
+
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 
@@ -393,7 +396,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 
 			mockPrompt: func(m *mocks.Mockprompter) {},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
-				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("no expose"))
+				m.EXPECT().GetExposedPorts().Return(nil, errors.New("no expose"))
 			},
 			mockSel:          func(m *mocks.MockdockerfileSelector) {},
 			mocktopicSel:     func(m *mocks.MocktopicSelector) {},
@@ -411,7 +414,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 					Return(defaultSvcPortString, nil)
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
-				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("no expose"))
+				m.EXPECT().GetExposedPorts().Return(nil, errors.New("no expose"))
 			},
 			mockSel:          func(m *mocks.MockdockerfileSelector) {},
 			mocktopicSel:     func(m *mocks.MocktopicSelector) {},
@@ -429,7 +432,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 					Return("", errors.New("some error"))
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
-				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("expose error"))
+				m.EXPECT().GetExposedPorts().Return(nil, errors.New("expose error"))
 			},
 			mockSel:          func(m *mocks.MockdockerfileSelector) {},
 			mocktopicSel:     func(m *mocks.MocktopicSelector) {},
@@ -447,7 +450,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 					Return("100000", errors.New("some error"))
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
-				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("no expose"))
+				m.EXPECT().GetExposedPorts().Return(nil, errors.New("no expose"))
 			},
 			mockSel:          func(m *mocks.MockdockerfileSelector) {},
 			mocktopicSel:     func(m *mocks.MocktopicSelector) {},
@@ -463,7 +466,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockPrompt: func(m *mocks.Mockprompter) {
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
-				m.EXPECT().GetExposedPorts().Return([]uint16{80}, nil)
+				m.EXPECT().GetExposedPorts().Return([]dockerfile.Port{{Port: 80, Protocol: "", RawString: "80"}}, nil)
 			},
 			mockSel:          func(m *mocks.MockdockerfileSelector) {},
 			mocktopicSel:     func(m *mocks.MocktopicSelector) {},
@@ -623,7 +626,7 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:           "frontend",
 						Type:           "Load Balanced Web Service",
 						DockerfilePath: "./Dockerfile",
-						Platform:       nil,
+						Platform:       manifest.PlatformArgsOrString{},
 					},
 					Port: 80,
 				}).Return("manifest/path", nil)
@@ -650,7 +653,7 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:           "frontend",
 						Type:           "Backend Service",
 						DockerfilePath: "./Dockerfile",
-						Platform:       nil,
+						Platform:       manifest.PlatformArgsOrString{},
 					},
 				}).Return("manifest/path", nil)
 			},
@@ -676,7 +679,7 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:           "frontend",
 						Type:           "Worker Service",
 						DockerfilePath: "./Dockerfile",
-						Platform:       nil,
+						Platform:       manifest.PlatformArgsOrString{},
 					},
 				}).Return("manifest/path", nil)
 			},
@@ -693,8 +696,8 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 					gomock.Any(),
 				).Return([]manifest.TopicSubscription{
 					{
-						Name:    "thetopic",
-						Service: "theservice",
+						Name:    aws.String("thetopic"),
+						Service: aws.String("theservice"),
 					},
 				}, nil)
 			},
@@ -715,7 +718,7 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:     "backend",
 						Type:     "Backend Service",
 						Image:    "nginx:latest",
-						Platform: nil,
+						Platform: manifest.PlatformArgsOrString{},
 					},
 				}).Return("manifest/path", nil)
 			},
@@ -740,7 +743,7 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:     "frontend",
 						Type:     "Load Balanced Web Service",
 						Image:    "nginx:latest",
-						Platform: nil,
+						Platform: manifest.PlatformArgsOrString{},
 					},
 				}).Return("manifest/path", nil)
 			},
