@@ -49,6 +49,7 @@ type taskExecOpts struct {
 	newTaskSel         func(*session.Session) runningTaskSelector
 	configSel          appEnvSelector
 	newCommandExecutor func(*session.Session) ecsCommandExecutor
+	provider           sessionProvider
 
 	task *awsecs.Task
 }
@@ -71,6 +72,7 @@ func newTaskExecOpts(vars taskExecVars) (*taskExecOpts, error) {
 		newCommandExecutor: func(s *session.Session) ecsCommandExecutor {
 			return awsecs.New(s)
 		},
+		provider: sessions.NewProvider(),
 	}, nil
 }
 
@@ -147,7 +149,7 @@ func (o *taskExecOpts) Execute() error {
 }
 
 func (o *taskExecOpts) selectTaskInDefaultCluster() error {
-	sess, err := sessions.NewProvider().Default()
+	sess, err := o.provider.Default()
 	if err != nil {
 		return fmt.Errorf("create default session: %w", err)
 	}
@@ -165,7 +167,7 @@ func (o *taskExecOpts) selectTaskInAppEnvCluster() error {
 	if err != nil {
 		return fmt.Errorf("get environment %s: %w", o.envName, err)
 	}
-	sess, err := sessions.NewProvider().FromRole(env.ManagerRoleARN, env.Region)
+	sess, err := o.provider.FromRole(env.ManagerRoleARN, env.Region)
 	if err != nil {
 		return fmt.Errorf("get session from role %s and region %s: %w", env.ManagerRoleARN, env.Region, err)
 	}
@@ -179,15 +181,14 @@ func (o *taskExecOpts) selectTaskInAppEnvCluster() error {
 }
 
 func (o *taskExecOpts) configSession() (*session.Session, error) {
-	sessProvider := sessions.NewProvider()
 	if o.useDefault {
-		return sessProvider.Default()
+		return o.provider.Default()
 	}
 	env, err := o.store.GetEnvironment(o.appName, o.envName)
 	if err != nil {
 		return nil, fmt.Errorf("get environment %s: %w", o.envName, err)
 	}
-	return sessProvider.FromRole(env.ManagerRoleARN, env.Region)
+	return o.provider.FromRole(env.ManagerRoleARN, env.Region)
 }
 
 // buildTaskExecCmd builds the command for execute a running container in a one-off task.
