@@ -9,9 +9,12 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/aws/aws-sdk-go/aws/session"
+
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 
 	"github.com/aws/copilot-cli/internal/pkg/ecs"
+	ecsMocks "github.com/aws/copilot-cli/internal/pkg/ecs/mocks"
 
 	"github.com/aws/copilot-cli/internal/pkg/cli/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
@@ -621,6 +624,7 @@ type runTaskMocks struct {
 	eventsWriter         *mocks.MockeventsWriter
 	defaultClusterGetter *mocks.MockdefaultClusterGetter
 	publicIPGetter       *mocks.MockpublicIPGetter
+	provider             *mocks.MocksessionProvider
 }
 
 func mockHasDefaultCluster(m runTaskMocks) {
@@ -659,6 +663,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 	}{
 		"check if default cluster exists if deploying to default cluster": {
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
 				m.defaultClusterGetter.EXPECT().HasDefaultCluster().Return(true, nil)
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).Return(nil).AnyTimes()
@@ -675,6 +680,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 					Return(&config.Environment{
 						ExecutionRoleARN: "env execution role",
 					}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any())
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any(), gomock.Any()).Return(nil).AnyTimes()
 				mockRepositoryAnytime(m)
 				m.runner.EXPECT().Run().AnyTimes()
@@ -682,6 +688,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		},
 		"error deploying resources": {
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
 				m.deployer.EXPECT().DeployTask(gomock.Any(), &deploy.CreateTaskResourcesInput{
 					Name:       inGroupName,
@@ -695,6 +702,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		},
 		"error updating resources": {
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
 				m.deployer.EXPECT().DeployTask(gomock.Any(), &deploy.CreateTaskResourcesInput{
 					Name:       inGroupName,
@@ -716,6 +724,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		},
 		"error running tasks": {
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).Return(nil).Times(2)
 				mockRepositoryAnytime(m)
@@ -731,6 +740,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 					Return(&config.Environment{
 						ExecutionRoleARN: "env execution role",
 					}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any())
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any(), gomock.Len(1)).AnyTimes() // NOTE: matching length because gomock is unable to match function arguments.
 				mockRepositoryAnytime(m)
 				m.runner.EXPECT().Run().AnyTimes()
@@ -739,6 +749,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		},
 		"deploy without execution role option if env is empty": {
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).Times(0)
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any(), gomock.Len(0)).AnyTimes() // NOTE: matching length because gomock is unable to match function arguments.
 				mockRepositoryAnytime(m)
@@ -749,6 +760,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		"append 'latest' to image tag": {
 			inTag: tag,
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).AnyTimes()
 				m.repository.EXPECT().BuildAndPush(gomock.Any(), gomock.Eq(
@@ -769,6 +781,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 			inCommand:    `/bin/sh -c "curl $ECS_CONTAINER_METADATA_URI_V4"`,
 			inEntryPoint: `exec "some command"`,
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
 				m.deployer.EXPECT().DeployTask(gomock.Any(), &deploy.CreateTaskResourcesInput{
 					Name:  inGroupName,
@@ -796,6 +809,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		},
 		"fail to get ENI information for some tasks": {
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).AnyTimes()
 				m.runner.EXPECT().Run().Return([]*task.Task{
 					{
@@ -816,6 +830,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		},
 		"fail to get public ips": {
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).AnyTimes()
 				m.runner.EXPECT().Run().Return([]*task.Task{
 					{
@@ -833,6 +848,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 			inFollow: true,
 			inImage:  "image",
 			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).AnyTimes()
 				m.runner.EXPECT().Run().Return([]*task.Task{
 					{
@@ -862,6 +878,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 				eventsWriter:         mocks.NewMockeventsWriter(ctrl),
 				defaultClusterGetter: mocks.NewMockdefaultClusterGetter(ctrl),
 				publicIPGetter:       mocks.NewMockpublicIPGetter(ctrl),
+				provider:             mocks.NewMocksessionProvider(ctrl),
 			}
 			tc.setupMocks(mocks)
 
@@ -877,8 +894,9 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 					command:    tc.inCommand,
 					entrypoint: tc.inEntryPoint,
 				},
-				spinner: &mockSpinner{},
-				store:   mocks.store,
+				spinner:  &mockSpinner{},
+				store:    mocks.store,
+				provider: mocks.provider,
 			}
 			opts.configureRuntimeOpts = func() error {
 				opts.runner = mocks.runner
@@ -911,13 +929,18 @@ type mockRunTaskRequester struct {
 	mockRunTaskRequestFromJob        func(client ecs.JobDescriber, app, env, job string) (*ecs.RunTaskRequest, error)
 }
 
+type taskRunMocks struct {
+	store    *mocks.Mockstore
+	provider *mocks.MocksessionProvider
+}
+
 func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 	wantedCommand := ecs.RunTaskRequest{}
 
 	testCases := map[string]struct {
 		inGenerateCommandTarget string
 
-		setupMockStore       func(m *mocks.Mockstore)
+		setUpMocks           func(m *taskRunMocks)
 		mockRunTaskRequester mockRunTaskRequester
 
 		wantedCommand *ecs.RunTaskRequest
@@ -925,6 +948,9 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 	}{
 		"should generate a command given an service ARN": {
 			inGenerateCommandTarget: "arn:aws:ecs:us-east-1:123456789012:service/crowded-cluster/good-service",
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromECSService: func(client ecs.ECSServiceDescriber, cluster string, service string) (*ecs.RunTaskRequest, error) {
 					return &wantedCommand, nil
@@ -934,6 +960,9 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"fail to generate a command given an service ARN": {
 			inGenerateCommandTarget: "arn:aws:ecs:us-east-1:123456789012:service/crowded-cluster/good-service",
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromECSService: func(client ecs.ECSServiceDescriber, cluster string, service string) (*ecs.RunTaskRequest, error) {
 					return nil, errors.New("some error")
@@ -943,6 +972,9 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"should generate a command given a cluster/service target": {
 			inGenerateCommandTarget: "crowded-cluster/good-service",
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromECSService: func(client ecs.ECSServiceDescriber, cluster string, service string) (*ecs.RunTaskRequest, error) {
 					return &wantedCommand, nil
@@ -952,6 +984,9 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"fail to generate a command given a cluster/service target": {
 			inGenerateCommandTarget: "crowded-cluster/good-service",
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromECSService: func(client ecs.ECSServiceDescriber, cluster string, service string) (*ecs.RunTaskRequest, error) {
 					return nil, errors.New("some error")
@@ -961,9 +996,10 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"should generate a command given an app/env/svc target": {
 			inGenerateCommandTarget: "good-app/good-env/good-service",
-			setupMockStore: func(m *mocks.Mockstore) {
-				m.EXPECT().GetJob("good-app", "good-service").Return(nil, &config.ErrNoSuchJob{})
-				m.EXPECT().GetService("good-app", "good-service").Return(&config.Workload{}, nil)
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+				m.store.EXPECT().GetJob("good-app", "good-service").Return(nil, &config.ErrNoSuchJob{})
+				m.store.EXPECT().GetService("good-app", "good-service").Return(&config.Workload{}, nil)
 			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromService: func(client ecs.ServiceDescriber, app, env, svc string) (*ecs.RunTaskRequest, error) {
@@ -974,9 +1010,10 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"fail to generate a command given an app/env/svc target": {
 			inGenerateCommandTarget: "good-app/good-env/good-service",
-			setupMockStore: func(m *mocks.Mockstore) {
-				m.EXPECT().GetJob("good-app", "good-service").Return(nil, &config.ErrNoSuchJob{})
-				m.EXPECT().GetService("good-app", "good-service").Return(&config.Workload{}, nil)
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+				m.store.EXPECT().GetJob("good-app", "good-service").Return(nil, &config.ErrNoSuchJob{})
+				m.store.EXPECT().GetService("good-app", "good-service").Return(&config.Workload{}, nil)
 			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromService: func(client ecs.ServiceDescriber, app, env, svc string) (*ecs.RunTaskRequest, error) {
@@ -987,8 +1024,9 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"should generate a command given an app/env/job target": {
 			inGenerateCommandTarget: "good-app/good-env/good-job",
-			setupMockStore: func(m *mocks.Mockstore) {
-				m.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+				m.store.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
 			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromJob: func(client ecs.JobDescriber, app, env, svc string) (*ecs.RunTaskRequest, error) {
@@ -999,8 +1037,9 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"fail to generate a command given an app/env/job target": {
 			inGenerateCommandTarget: "good-app/good-env/good-job",
-			setupMockStore: func(m *mocks.Mockstore) {
-				m.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+				m.store.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
 			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromJob: func(client ecs.JobDescriber, app, env, svc string) (*ecs.RunTaskRequest, error) {
@@ -1011,30 +1050,36 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 		},
 		"fail to determine if the workload is a job given an app/env/workload target": {
 			inGenerateCommandTarget: "good-app/good-env/bad-workload",
-			setupMockStore: func(m *mocks.Mockstore) {
-				m.EXPECT().GetJob("good-app", "bad-workload").Return(nil, errors.New("some error"))
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+				m.store.EXPECT().GetJob("good-app", "bad-workload").Return(nil, errors.New("some error"))
 			},
 			wantedError: fmt.Errorf("determine whether workload bad-workload is a job: some error"),
 		},
 		"fail to determine if the workload is a service given an app/env/workload target": {
 			inGenerateCommandTarget: "good-app/good-env/bad-workload",
-			setupMockStore: func(m *mocks.Mockstore) {
-				m.EXPECT().GetJob("good-app", "bad-workload").Return(nil, &config.ErrNoSuchJob{})
-				m.EXPECT().GetService("good-app", "bad-workload").Return(nil, errors.New("some error"))
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+				m.store.EXPECT().GetJob("good-app", "bad-workload").Return(nil, &config.ErrNoSuchJob{})
+				m.store.EXPECT().GetService("good-app", "bad-workload").Return(nil, errors.New("some error"))
 			},
 			wantedError: fmt.Errorf("determine whether workload bad-workload is a service: some error"),
 		},
 		"workload is neither a job nor a service": {
 			inGenerateCommandTarget: "good-app/good-env/bad-workload",
-			setupMockStore: func(m *mocks.Mockstore) {
-				m.EXPECT().GetJob("good-app", "bad-workload").Return(nil, &config.ErrNoSuchJob{})
-				m.EXPECT().GetService("good-app", "bad-workload").Return(nil, &config.ErrNoSuchService{})
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+				m.store.EXPECT().GetJob("good-app", "bad-workload").Return(nil, &config.ErrNoSuchJob{})
+				m.store.EXPECT().GetService("good-app", "bad-workload").Return(nil, &config.ErrNoSuchService{})
 			},
 			wantedError: fmt.Errorf("workload bad-workload is neither a service nor a job"),
 		},
 		"invalid input": {
 			inGenerateCommandTarget: "invalid/illegal/not-good/input/is/bad",
-			wantedError:             errors.New("invalid input to --generate-cmd: must be of format <cluster>/<service> or <app>/<env>/<workload>"),
+			setUpMocks: func(m *taskRunMocks) {
+				m.provider.EXPECT().Default()
+			},
+			wantedError: errors.New("invalid input to --generate-cmd: must be of format <cluster>/<service> or <app>/<env>/<workload>"),
 		},
 	}
 	for name, tc := range testCases {
@@ -1042,15 +1087,29 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 			ctrl := gomock.NewController(t)
 			defer ctrl.Finish()
 
-			mockStore := mocks.NewMockstore(ctrl)
-			if tc.setupMockStore != nil {
-				tc.setupMockStore(mockStore)
+			m := &taskRunMocks{
+				store:    mocks.NewMockstore(ctrl),
+				provider: mocks.NewMocksessionProvider(ctrl),
+			}
+			if tc.setUpMocks != nil {
+				tc.setUpMocks(m)
 			}
 			opts := &runTaskOpts{
 				runTaskVars: runTaskVars{
 					generateCommandTarget: tc.inGenerateCommandTarget,
 				},
-				store: mockStore,
+				store:    m.store,
+				provider: m.provider,
+
+				configureECSServiceDescriber: func(session *session.Session) ecs.ECSServiceDescriber {
+					return ecsMocks.NewMockECSServiceDescriber(ctrl)
+				},
+				configureJobDescriber: func(session *session.Session) ecs.JobDescriber {
+					return ecsMocks.NewMockJobDescriber(ctrl)
+				},
+				configureServiceDescriber: func(session *session.Session) ecs.ServiceDescriber {
+					return ecsMocks.NewMockServiceDescriber(ctrl)
+				},
 
 				runTaskRequestFromECSService: tc.mockRunTaskRequester.mockRunTaskRequestFromECSService,
 				runTaskRequestFromService:    tc.mockRunTaskRequester.mockRunTaskRequestFromService,
