@@ -11,7 +11,6 @@ import (
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
-	"github.com/aws/aws-sdk-go/service/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/addon"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack/mocks"
@@ -92,8 +91,8 @@ func TestLoadBalancedWebService_StackName(t *testing.T) {
 }
 
 func TestLoadBalancedWebService_Template(t *testing.T) {
-	var overridenContainerHealthCheck = ecs.HealthCheck{
-		Command:     []*string{aws.String("CMD-SHELL"), aws.String("curl -f http://localhost/ || exit 1")},
+	var overridenContainerHealthCheck = template.ContainerHealthCheck{
+		Command:     []string{"CMD-SHELL", "curl -f http://localhost/ || exit 1"},
 		Interval:    aws.Int64(10),
 		StartPeriod: aws.Int64(0),
 		Timeout:     aws.Int64(5),
@@ -107,15 +106,15 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 		Path: "frontend",
 		Port: 80,
 	})
-	testLBWebServiceManifest.ImageConfig.HealthCheck = &manifest.ContainerHealthCheck{
+	testLBWebServiceManifest.ImageConfig.HealthCheck = manifest.ContainerHealthCheck{
 		Retries: aws.Int(5),
 	}
-	testLBWebServiceManifest.Alias = &manifest.Alias{String: aws.String("mockAlias")}
-	testLBWebServiceManifest.EntryPoint = &manifest.EntryPointOverride{
+	testLBWebServiceManifest.Alias = manifest.Alias{String: aws.String("mockAlias")}
+	testLBWebServiceManifest.EntryPoint = manifest.EntryPointOverride{
 		String:      nil,
 		StringSlice: []string{"/bin/echo", "hello"},
 	}
-	testLBWebServiceManifest.Command = &manifest.CommandOverride{
+	testLBWebServiceManifest.Command = manifest.CommandOverride{
 		String:      nil,
 		StringSlice: []string{"world"},
 	}
@@ -341,7 +340,7 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 	testLBWebServiceManifest.Count = manifest.Count{
 		Value: aws.Int(1),
 		AdvancedCount: manifest.AdvancedCount{
-			Range: &manifest.Range{
+			Range: manifest.Range{
 				Value: &testLBWebServiceManifestRange,
 			},
 		},
@@ -350,7 +349,7 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 	testLBWebServiceManifestWithBadCountRange := manifest.IntRangeBand("badCount")
 	testLBWebServiceManifestWithBadCount.Count = manifest.Count{
 		AdvancedCount: manifest.AdvancedCount{
-			Range: &manifest.Range{
+			Range: manifest.Range{
 				Value: &testLBWebServiceManifestWithBadCountRange,
 			},
 		},
