@@ -87,7 +87,7 @@ func TestRequestDrivenWebService_NewRequestDrivenWebService(t *testing.T) {
 						env:   testEnvName,
 						app:   testAppName,
 						rc:    RuntimeConfig{},
-						image: testRDWebServiceManifest.ImageConfig,
+						image: testRDWebServiceManifest.ImageConfig.Image,
 					},
 					instanceConfig: testRDWebServiceManifest.InstanceConfig,
 					imageConfig:    testRDWebServiceManifest.ImageConfig,
@@ -165,7 +165,7 @@ func TestRequestDrivenWebService_NewRequestDrivenWebServiceWithAlias(t *testing.
 						env:   testEnvName,
 						app:   testAppName,
 						rc:    RuntimeConfig{},
-						image: testRDWebServiceManifest.ImageConfig,
+						image: testRDWebServiceManifest.ImageConfig.Image,
 					},
 					instanceConfig: testRDWebServiceManifest.InstanceConfig,
 					imageConfig:    testRDWebServiceManifest.ImageConfig,
@@ -459,7 +459,7 @@ func TestRequestDrivenWebService_Parameters(t *testing.T) {
 						name:  aws.StringValue(testRDWebServiceManifest.Name),
 						env:   testEnvName,
 						app:   testAppName,
-						image: tc.imageConfig,
+						image: tc.imageConfig.Image,
 					},
 					instanceConfig: tc.instanceConfig,
 					imageConfig:    tc.imageConfig,
