@@ -4,10 +4,8 @@
 package stack
 
 import (
-	"errors"
 	"fmt"
 	"hash/crc32"
-	"regexp"
 	"strings"
 	"time"
 
@@ -35,76 +33,36 @@ const (
 	defaultWritePermission = false
 )
 
-// Min and Max values for task ephemeral storage in GiB.
-const (
-	ephemeralMinValueGiB = 21
-	ephemeralMaxValueGiB = 200
-)
-
 // Supported capacityproviders for Fargate services
 const (
 	capacityProviderFargateSpot = "FARGATE_SPOT"
 	capacityProviderFargate     = "FARGATE"
 )
 
-// Time interval options.
-const (
-	retentionMinValueSeconds = 0
-	retentionMaxValueSeconds = 1209600
-	delayMinValueSeconds     = 0
-	delayMaxValueSeconds     = 900
-	timeoutMinValueSeconds   = 0
-	timeoutMaxValueSeconds   = 43200
-)
-
 var (
-	errEphemeralBadSize  = errors.New("ephemeral storage must be between 20 GiB and 200 GiB")
-	errInvalidSpotConfig = errors.New(`"count.spot" and "count.range" cannot be specified together`)
-
-	taskDefOverrideRulePrefixes      = []string{"Resources", "TaskDefinition", "Properties"}
-	invalidTaskDefOverridePathRegexp = []string{`Family`, `ContainerDefinitions\[\d+\].Name`}
+	taskDefOverrideRulePrefixes = []string{"Resources", "TaskDefinition", "Properties"}
 )
 
-type convertSidecarOpts struct {
-	sidecarConfig map[string]*manifest.SidecarConfig
-	imageConfig   *manifest.Image
-	workloadName  string
-}
-
 // convertSidecar converts the manifest sidecar configuration into a format parsable by the templates pkg.
-func convertSidecar(s convertSidecarOpts) ([]*template.SidecarOpts, error) {
-	if s.sidecarConfig == nil {
+func convertSidecar(s map[string]*manifest.SidecarConfig) ([]*template.SidecarOpts, error) {
+	if s == nil {
 		return nil, nil
 	}
-	if err := validateNoCircularDependencies(s); err != nil {
-		return nil, err
-	}
 	var sidecars []*template.SidecarOpts
-	for name, config := range s.sidecarConfig {
+	for name, config := range s {
 		port, protocol, err := parsePortMapping(config.Port)
 		if err != nil {
 			return nil, err
 		}
-		if err := validateSidecarMountPoints(config.MountPoints); err != nil {
-			return nil, err
-		}
-		convertDependsOnStatus(&s)
-		if err := validateSidecarDependsOn(*config, name, s); err != nil {
-			return nil, err
-		}
-
 		entrypoint, err := convertEntryPoint(config.EntryPoint)
 		if err != nil {
 			return nil, err
 		}
-
 		command, err := convertCommand(config.Command)
 		if err != nil {
 			return nil, err
 		}
-
 		mp := convertSidecarMountPoints(config.MountPoints)
-
 		sidecars = append(sidecars, &template.SidecarOpts{
 			Name:         aws.String(name),
 			Image:        config.Image,
@@ -116,43 +74,40 @@ func convertSidecar(s convertSidecarOpts) ([]*template.SidecarOpts, error) {
 			Variables:    config.Variables,
 			MountPoints:  mp,
 			DockerLabels: config.DockerLabels,
-			DependsOn:    config.DependsOn,
+			DependsOn:    convertDependsOn(config.DependsOn),
 			EntryPoint:   entrypoint,
+			HealthCheck:  convertContainerHealthCheck(config.HealthCheck),
 			Command:      command,
 		})
 	}
 	return sidecars, nil
 }
 
-// convertDependsOnStatus converts image and sidecar depends on fields to have upper case statuses
-func convertDependsOnStatus(s *convertSidecarOpts) {
-	if s.sidecarConfig != nil {
-		for _, sidecar := range s.sidecarConfig {
-			if sidecar.DependsOn == nil {
-				continue
-			}
-			for name, status := range sidecar.DependsOn {
-				sidecar.DependsOn[name] = strings.ToUpper(status)
-			}
-		}
+func convertContainerHealthCheck(hc manifest.ContainerHealthCheck) *template.ContainerHealthCheck {
+	if hc.IsEmpty() {
+		return nil
 	}
-	if s.imageConfig != nil && s.imageConfig.DependsOn != nil {
-		for name, status := range s.imageConfig.DependsOn {
-			s.imageConfig.DependsOn[name] = strings.ToUpper(status)
-		}
+	// Make sure that unset fields in the healthcheck gets a default value.
+	hc.ApplyIfNotSet(manifest.NewDefaultContainerHealthCheck())
+	return &template.ContainerHealthCheck{
+		Command:     hc.Command,
+		Interval:    aws.Int64(int64(hc.Interval.Seconds())),
+		Retries:     aws.Int64(int64(aws.IntValue(hc.Retries))),
+		StartPeriod: aws.Int64(int64(hc.StartPeriod.Seconds())),
+		Timeout:     aws.Int64(int64(hc.Timeout.Seconds())),
 	}
 }
 
-// convertDependsOn converts an Image DependsOn field to a template DependsOn version
-func convertImageDependsOn(s convertSidecarOpts) (map[string]string, error) {
-	if s.imageConfig == nil || s.imageConfig.DependsOn == nil {
-		return nil, nil
+// convertDependsOn converts image and sidecar depends on fields to have upper case statuses.
+func convertDependsOn(d manifest.DependsOn) map[string]string {
+	if d == nil {
+		return nil
 	}
-	convertDependsOnStatus(&s)
-	if err := validateImageDependsOn(s); err != nil {
-		return nil, err
+	dependsOn := make(map[string]string)
+	for name, status := range d {
+		dependsOn[name] = strings.ToUpper(status)
 	}
-	return s.imageConfig.DependsOn, nil
+	return dependsOn
 }
 
 // Valid sidecar portMapping example: 2000/udp, or 2000 (default to be tcp).
@@ -171,67 +126,46 @@ func parsePortMapping(s *string) (port *string, protocol *string, err error) {
 	}
 }
 
-func convertAdvancedCount(a *manifest.AdvancedCount) (*template.AdvancedCount, error) {
-	if a == nil {
-		return nil, nil
-	}
-
+func convertAdvancedCount(a manifest.AdvancedCount) (*template.AdvancedCount, error) {
 	if a.IsEmpty() {
 		return nil, nil
 	}
-
 	autoscaling, err := convertAutoscaling(a)
 	if err != nil {
 		return nil, err
 	}
-
-	cps, err := convertCapacityProviders(a)
-	if err != nil {
-		return nil, err
-	}
-
 	return &template.AdvancedCount{
 		Spot:        a.Spot,
 		Autoscaling: autoscaling,
-		Cps:         cps,
+		Cps:         convertCapacityProviders(a),
 	}, nil
 }
 
 // convertCapacityProviders transforms the manifest fields into a format
 // parsable by the templates pkg.
-func convertCapacityProviders(a *manifest.AdvancedCount) ([]*template.CapacityProviderStrategy, error) {
+func convertCapacityProviders(a manifest.AdvancedCount) []*template.CapacityProviderStrategy {
 	if a.IsEmpty() {
-		return nil, nil
+		return nil
 	}
-
-	if a.Spot != nil && a.Range != nil {
-		return nil, errInvalidSpotConfig
-	}
-
 	// return if autoscaling range specified without spot scaling
-	if a.Range != nil && a.Range.Value != nil {
-		return nil, nil
+	if !a.Range.IsEmpty() && a.Range.Value != nil {
+		return nil
 	}
-
 	var cps []*template.CapacityProviderStrategy
-
 	// if Spot specified as count, then weight on Spot CPS should be 1
 	cps = append(cps, &template.CapacityProviderStrategy{
 		Weight:           aws.Int(1),
 		CapacityProvider: capacityProviderFargateSpot,
 	})
-
 	// Return if only spot is specifed as count
-	if a.Range == nil {
-		return cps, nil
+	if a.Range.IsEmpty() {
+		return cps
 	}
-
 	// Scaling with spot
 	rc := a.Range.RangeConfig
 	if !rc.IsEmpty() {
 		spotFrom := aws.IntValue(rc.SpotFrom)
 		min := aws.IntValue(rc.Min)
-
 		// If spotFrom value is not equal to the autoscaling min, then
 		// the base value on the Fargate Capacity provider must be set
 		// to one less than spotFrom
@@ -245,13 +179,12 @@ func convertCapacityProviders(a *manifest.AdvancedCount) ([]*template.CapacityPr
 			cps = append(cps, fgCapacity)
 		}
 	}
-
-	return cps, nil
+	return cps
 }
 
 // convertAutoscaling converts the service's Auto Scaling configuration into a format parsable
 // by the templates pkg.
-func convertAutoscaling(a *manifest.AdvancedCount) (*template.AutoscalingOpts, error) {
+func convertAutoscaling(a manifest.AdvancedCount) (*template.AutoscalingOpts, error) {
 	if a.IsEmpty() {
 		return nil, nil
 	}
@@ -280,6 +213,15 @@ func convertAutoscaling(a *manifest.AdvancedCount) (*template.AutoscalingOpts, e
 		responseTime := float64(*a.ResponseTime) / float64(time.Second)
 		autoscalingOpts.ResponseTime = aws.Float64(responseTime)
 	}
+	if !a.QueueScaling.IsEmpty() {
+		acceptableBacklog, err := a.QueueScaling.AcceptableBacklogPerTask()
+		if err != nil {
+			return nil, err
+		}
+		autoscalingOpts.QueueDelay = &template.AutoscalingQueueDelayOpts{
+			AcceptableBacklogPerTask: acceptableBacklog,
+		}
+	}
 	return &autoscalingOpts, nil
 }
 
@@ -318,14 +260,10 @@ func convertExecuteCommand(e *manifest.ExecuteCommand) *template.ExecuteCommandO
 	return &template.ExecuteCommandOpts{}
 }
 
-func convertLogging(lc *manifest.Logging) *template.LogConfigOpts {
-	if lc == nil {
+func convertLogging(lc manifest.Logging) *template.LogConfigOpts {
+	if lc.IsEmpty() {
 		return nil
 	}
-	return logConfigOpts(lc)
-}
-
-func logConfigOpts(lc *manifest.Logging) *template.LogConfigOpts {
 	return &template.LogConfigOpts{
 		Image:          lc.LogImage(),
 		ConfigFile:     lc.ConfigFile,
@@ -339,9 +277,6 @@ func convertTaskDefOverrideRules(inRules []manifest.OverrideRule) []override.Rul
 	var res []override.Rule
 	suffixStr := strings.Join(taskDefOverrideRulePrefixes, override.PathSegmentSeparator)
 	for _, r := range inRules {
-		if !isValidTaskDefOverridePath(r.Path) {
-			continue
-		}
 		res = append(res, override.Rule{
 			Path:  strings.Join([]string{suffixStr, r.Path}, override.PathSegmentSeparator),
 			Value: r.Value,
@@ -350,70 +285,28 @@ func convertTaskDefOverrideRules(inRules []manifest.OverrideRule) []override.Rul
 	return res
 }
 
-func isValidTaskDefOverridePath(path string) bool {
-	for _, s := range invalidTaskDefOverridePathRegexp {
-		re := regexp.MustCompile(fmt.Sprintf(`^%s$`, s))
-		if re.MatchString(path) {
-			return false
-		}
-	}
-	return true
-}
-
 // convertStorageOpts converts a manifest Storage field into template data structures which can be used
 // to execute CFN templates
-func convertStorageOpts(wlName *string, in *manifest.Storage) (*template.StorageOpts, error) {
-	if in == nil {
-		return nil, nil
-	}
-	if err := validateStorageConfig(in); err != nil {
-		return nil, err
-	}
-	mv, err := convertManagedFSInfo(wlName, in.Volumes)
-	if err != nil {
-		return nil, err
-	}
-	v, err := convertVolumes(in.Volumes)
-	if err != nil {
-		return nil, err
-	}
-	mp, err := convertMountPoints(in.Volumes)
-	if err != nil {
-		return nil, err
-	}
-	perms, err := convertEFSPermissions(in.Volumes)
-	if err != nil {
-		return nil, err
-	}
-	ephemeral, err := convertEphemeral(in.Ephemeral)
-	if err != nil {
-		return nil, err
+func convertStorageOpts(wlName *string, in manifest.Storage) *template.StorageOpts {
+	if in.IsEmpty() {
+		return nil
 	}
 	return &template.StorageOpts{
-		Ephemeral:         ephemeral,
-		Volumes:           v,
-		MountPoints:       mp,
-		EFSPerms:          perms,
-		ManagedVolumeInfo: mv,
-	}, nil
+		Ephemeral:         convertEphemeral(in.Ephemeral),
+		Volumes:           convertVolumes(in.Volumes),
+		MountPoints:       convertMountPoints(in.Volumes),
+		EFSPerms:          convertEFSPermissions(in.Volumes),
+		ManagedVolumeInfo: convertManagedFSInfo(wlName, in.Volumes),
+	}
 }
 
-func convertEphemeral(in *int) (*int, error) {
-	if in == nil {
-		return nil, nil
-	}
-
+func convertEphemeral(in *int) *int {
 	// Min value for extensible ephemeral storage is 21; if customer specifies 20, which is the default size,
 	// we shouldn't let CF error out. Instead, we'll just omit it from the config.
 	if aws.IntValue(in) == 20 {
-		return nil, nil
+		return nil
 	}
-
-	if aws.IntValue(in) < ephemeralMinValueGiB || aws.IntValue(in) > ephemeralMaxValueGiB {
-		return nil, errEphemeralBadSize
-	}
-
-	return in, nil
+	return in
 }
 
 // convertSidecarMountPoints is used to convert from manifest to template objects.
@@ -441,18 +334,18 @@ func convertMountPoint(sourceVolume, containerPath *string, readOnly *bool) *tem
 	}
 }
 
-func convertMountPoints(input map[string]*manifest.Volume) ([]*template.MountPoint, error) {
+func convertMountPoints(input map[string]*manifest.Volume) []*template.MountPoint {
 	if len(input) == 0 {
-		return nil, nil
+		return nil
 	}
 	var output []*template.MountPoint
 	for name, volume := range input {
 		output = append(output, convertMountPoint(aws.String(name), volume.ContainerPath, volume.ReadOnly))
 	}
-	return output, nil
+	return output
 }
 
-func convertEFSPermissions(input map[string]*manifest.Volume) ([]*template.EFSPermission, error) {
+func convertEFSPermissions(input map[string]*manifest.Volume) []*template.EFSPermission {
 	var output []*template.EFSPermission
 	for _, volume := range input {
 		// If there's no EFS configuration, we don't need to generate any permissions.
@@ -473,36 +366,24 @@ func convertEFSPermissions(input map[string]*manifest.Volume) ([]*template.EFSPe
 		if volume.ReadOnly != nil {
 			write = !aws.BoolValue(volume.ReadOnly)
 		}
-		var accessPointID *string
-		if volume.EFS.Advanced.AuthConfig != nil {
-			accessPointID = volume.EFS.Advanced.AuthConfig.AccessPointID
-		}
+		accessPointID := volume.EFS.Advanced.AuthConfig.AccessPointID
 		output = append(output, &template.EFSPermission{
 			Write:         write,
 			AccessPointID: accessPointID,
 			FilesystemID:  volume.EFS.Advanced.FileSystemID,
 		})
 	}
-	return output, nil
+	return output
 }
 
-func convertManagedFSInfo(wlName *string, input map[string]*manifest.Volume) (*template.ManagedVolumeCreationInfo, error) {
+func convertManagedFSInfo(wlName *string, input map[string]*manifest.Volume) *template.ManagedVolumeCreationInfo {
 	var output *template.ManagedVolumeCreationInfo
 	for name, volume := range input {
-		if volume.EmptyVolume() {
+		if volume.EmptyVolume() || !volume.EFS.UseManagedFS() {
 			continue
 		}
-		if !volume.EFS.UseManagedFS() {
-			continue
-		}
-
-		if output != nil {
-			return nil, fmt.Errorf("cannot specify more than one managed volume per service")
-		}
-
 		uid := volume.EFS.Advanced.UID
 		gid := volume.EFS.Advanced.GID
-
 		if uid == nil && gid == nil {
 			crc := aws.Uint32(getRandomUIDGID(wlName))
 			uid = crc
@@ -515,7 +396,7 @@ func convertManagedFSInfo(wlName *string, input map[string]*manifest.Volume) (*t
 			GID:     gid,
 		}
 	}
-	return output, nil
+	return output
 }
 
 // getRandomUIDGID returns the 32-bit checksum of the service name for use as CreationInfo in the EFS Access Point.
@@ -525,7 +406,7 @@ func getRandomUIDGID(name *string) uint32 {
 	return crc32.ChecksumIEEE([]byte(aws.StringValue(name)))
 }
 
-func convertVolumes(input map[string]*manifest.Volume) ([]*template.Volume, error) {
+func convertVolumes(input map[string]*manifest.Volume) []*template.Volume {
 	var output []*template.Volume
 	for name, volume := range input {
 		// Volumes can contain either:
@@ -558,7 +439,7 @@ func convertVolumes(input map[string]*manifest.Volume) ([]*template.Volume, erro
 			},
 		)
 	}
-	return output, nil
+	return output
 }
 
 func convertEFSConfiguration(in manifest.EFSVolumeConfiguration) *template.EFSVolumeConfiguration {
@@ -569,7 +450,7 @@ func convertEFSConfiguration(in manifest.EFSVolumeConfiguration) *template.EFSVo
 	}
 	// Set default values for IAM and AccessPointID
 	iam := aws.String(defaultIAM)
-	if in.AuthConfig == nil {
+	if in.AuthConfig.IsEmpty() {
 		return &template.EFSVolumeConfiguration{
 			Filesystem:    in.FileSystemID,
 			RootDirectory: rootDir,
@@ -589,8 +470,8 @@ func convertEFSConfiguration(in manifest.EFSVolumeConfiguration) *template.EFSVo
 	}
 }
 
-func convertNetworkConfig(network *manifest.NetworkConfig) *template.NetworkOpts {
-	if network == nil || network.VPC == nil {
+func convertNetworkConfig(network manifest.NetworkConfig) *template.NetworkOpts {
+	if network.IsEmpty() {
 		return &template.NetworkOpts{
 			AssignPublicIP: template.EnablePublicIP,
 			SubnetsType:    template.PublicSubnetsPlacement,
@@ -601,44 +482,36 @@ func convertNetworkConfig(network *manifest.NetworkConfig) *template.NetworkOpts
 		SubnetsType:    template.PublicSubnetsPlacement,
 		SecurityGroups: network.VPC.SecurityGroups,
 	}
-	if aws.StringValue(network.VPC.Placement) != manifest.PublicSubnetPlacement {
+	if network.VPC.Placement == nil {
+		return opts
+	}
+	if *network.VPC.Placement != manifest.PublicSubnetPlacement {
 		opts.AssignPublicIP = template.DisablePublicIP
 		opts.SubnetsType = template.PrivateSubnetsPlacement
 	}
 	return opts
 }
 
-func convertAlias(alias *manifest.Alias) ([]string, error) {
-	if alias == nil {
-		return nil, nil
-	}
-
+func convertAlias(alias manifest.Alias) ([]string, error) {
 	out, err := alias.ToStringSlice()
 	if err != nil {
-		return nil, fmt.Errorf(`convert 'http.alias' to string slice: %w`, err)
+		return nil, fmt.Errorf(`convert "http.alias" to string slice: %w`, err)
 	}
 	return out, nil
 }
 
-func convertEntryPoint(entrypoint *manifest.EntryPointOverride) ([]string, error) {
-	if entrypoint == nil {
-		return nil, nil
-	}
-
+func convertEntryPoint(entrypoint manifest.EntryPointOverride) ([]string, error) {
 	out, err := entrypoint.ToStringSlice()
 	if err != nil {
-		return nil, fmt.Errorf(`convert 'entrypoint' to string slice: %w`, err)
+		return nil, fmt.Errorf(`convert "entrypoint" to string slice: %w`, err)
 	}
 	return out, nil
 }
 
-func convertCommand(command *manifest.CommandOverride) ([]string, error) {
-	if command == nil {
-		return nil, nil
-	}
+func convertCommand(command manifest.CommandOverride) ([]string, error) {
 	out, err := command.ToStringSlice()
 	if err != nil {
-		return nil, fmt.Errorf(`convert 'command' to string slice: %w`, err)
+		return nil, fmt.Errorf(`convert "command" to string slice: %w`, err)
 	}
 	return out, nil
 }
@@ -654,154 +527,96 @@ func convertPublish(topics []manifest.Topic, accountID, region, app, env, svc st
 	var publishers template.PublishOpts
 	// convert the topics to template Topics
 	for _, topic := range topics {
-		t, err := convertTopic(topic, accountID, partition.ID(), region, app, env, svc)
-		if err != nil {
-			return nil, err
-		}
-
-		publishers.Topics = append(publishers.Topics, t)
+		publishers.Topics = append(publishers.Topics, &template.Topic{
+			Name:      topic.Name,
+			AccountID: accountID,
+			Partition: partition.ID(),
+			Region:    region,
+			App:       app,
+			Env:       env,
+			Svc:       svc,
+		})
 	}
 
 	return &publishers, nil
 }
 
-func convertTopic(t manifest.Topic, accountID, partition, region, app, env, svc string) (*template.Topic, error) {
-	// topic should have a valid name and valid service worker names
-	if err := validatePubSubName(aws.StringValue(t.Name)); err != nil {
-		return nil, err
-	}
-	if err := validateWorkerNames(t.AllowedWorkers); err != nil {
-		return nil, err
-	}
-
-	return &template.Topic{
-		Name:           t.Name,
-		AllowedWorkers: t.AllowedWorkers,
-		AccountID:      accountID,
-		Partition:      partition,
-		Region:         region,
-		App:            app,
-		Env:            env,
-		Svc:            svc,
-	}, nil
-}
-
-func convertSubscribe(s *manifest.SubscribeConfig, validTopicARNs []string, accountID, region, app, env, svc string) (*template.SubscribeOpts, error) {
-	if s == nil || s.Topics == nil {
+func convertSubscribe(s manifest.SubscribeConfig, accountID, region, app, env, svc string) (*template.SubscribeOpts, error) {
+	if s.Topics == nil {
 		return nil, nil
 	}
-
 	sqsEndpoint, err := endpoints.DefaultResolver().EndpointFor(endpoints.SqsServiceID, region)
 	if err != nil {
 		return nil, err
 	}
-
 	var subscriptions template.SubscribeOpts
 	for _, sb := range s.Topics {
-		ts, err := convertTopicSubscription(sb, sqsEndpoint.URL, accountID, app, env, svc)
-		if err != nil {
-			return nil, err
-		}
-
+		ts := convertTopicSubscription(sb, sqsEndpoint.URL, accountID, app, env, svc)
 		subscriptions.Topics = append(subscriptions.Topics, ts)
 	}
-	queue, err := convertQueue(s.Queue, sqsEndpoint.URL, accountID, app, env, svc)
-	if err != nil {
-		return nil, err
-	}
-	subscriptions.Queue = queue
-
+	subscriptions.Queue = convertQueue(s.Queue)
 	return &subscriptions, nil
 }
 
-func convertTopicSubscription(t manifest.TopicSubscription, url, accountID, app, env, svc string) (*template.TopicSubscription, error) {
-	err := validateTopicSubscription(t)
-	if err != nil {
-		return nil, fmt.Errorf(`invalid topic subscription "%s": %w`, t.Name, err)
+func convertTopicSubscription(t manifest.TopicSubscription, url, accountID, app, env, svc string) *template.TopicSubscription {
+	if aws.BoolValue(t.Queue.Enabled) {
+		return &template.TopicSubscription{
+			Name:    t.Name,
+			Service: t.Service,
+			Queue:   &template.SQSQueue{},
+		}
 	}
-	queue, err := convertQueue(t.Queue, url, accountID, app, env, svc)
-	if err != nil {
-		return nil, fmt.Errorf(`invalid topic subscription "%s": %w`, t.Name, err)
-	}
-
 	return &template.TopicSubscription{
-		Name:    aws.String(t.Name),
-		Service: aws.String(t.Service),
-		Queue:   queue,
-	}, nil
+		Name:    t.Name,
+		Service: t.Service,
+		Queue:   convertQueue(t.Queue.Advanced),
+	}
 }
 
-func convertQueue(q *manifest.SQSQueue, url, accountID, app, env, svc string) (*template.SQSQueue, error) {
-	if q == nil {
-		return nil, nil
+func convertQueue(q manifest.SQSQueue) *template.SQSQueue {
+	if q.IsEmpty() {
+		return nil
 	}
-	retention, err := convertRetention(q.Retention)
-	if err != nil {
-		return nil, fmt.Errorf(" `retention` %w", err)
-	}
-	delay, err := convertDelay(q.Delay)
-	if err != nil {
-		return nil, fmt.Errorf("`delay` %w", err)
-	}
-	timeout, err := convertTimeout(q.Timeout)
-	if err != nil {
-		return nil, fmt.Errorf("`timeout` %w", err)
-	}
-	deadletter, err := convertDeadLetter(q.DeadLetter)
-	if err != nil {
-		return nil, err
-	}
-
 	return &template.SQSQueue{
-		Retention:  retention,
-		Delay:      delay,
-		Timeout:    timeout,
-		DeadLetter: deadletter,
-	}, nil
+		Retention:  convertRetention(q.Retention),
+		Delay:      convertDelay(q.Delay),
+		Timeout:    convertTimeout(q.Timeout),
+		DeadLetter: convertDeadLetter(q.DeadLetter),
+	}
 }
 
-func convertTime(t *time.Duration, floor, ceiling time.Duration) (*int64, error) {
+func convertTime(t *time.Duration) *int64 {
 	if t == nil {
-		return nil, nil
+		return nil
 	}
-
-	if err := validateTime(*t, floor, ceiling); err != nil {
-		return nil, err
-	}
-
-	return aws.Int64(int64(t.Seconds())), nil
+	return aws.Int64(int64(t.Seconds()))
 }
 
-func convertRetention(t *time.Duration) (*int64, error) {
-	return convertTime(t, retentionMinValueSeconds*time.Second, retentionMaxValueSeconds*time.Second)
+func convertRetention(t *time.Duration) *int64 {
+	return convertTime(t)
 }
 
-func convertDelay(t *time.Duration) (*int64, error) {
-	return convertTime(t, delayMinValueSeconds*time.Second, delayMaxValueSeconds*time.Second)
+func convertDelay(t *time.Duration) *int64 {
+	return convertTime(t)
 }
 
-func convertTimeout(t *time.Duration) (*int64, error) {
-	return convertTime(t, timeoutMinValueSeconds*time.Second, timeoutMaxValueSeconds*time.Second)
+func convertTimeout(t *time.Duration) *int64 {
+	return convertTime(t)
 }
 
-func convertDeadLetter(d *manifest.DeadLetterQueue) (*template.DeadLetterQueue, error) {
-	if d == nil {
-		return nil, nil
+func convertDeadLetter(d manifest.DeadLetterQueue) *template.DeadLetterQueue {
+	if d.IsEmpty() {
+		return nil
 	}
-	if err := validateDeadLetter(d); err != nil {
-		return nil, err
-	}
-
 	return &template.DeadLetterQueue{
 		Tries: d.Tries,
-	}, nil
+	}
 }
 
 func parseS3URLs(nameToS3URL map[string]string) (bucket *string, s3ObjectKeys map[string]*string, err error) {
 	if len(nameToS3URL) == 0 {
 		return nil, nil, nil
 	}
-
 	s3ObjectKeys = make(map[string]*string)
 	for fname, s3url := range nameToS3URL {
 		bucketName, key, err := s3.ParseURL(s3url)
@@ -819,11 +634,9 @@ func convertAppInformation(app deploy.AppInformation) (delegationRole *string, d
 	if role != "" {
 		delegationRole = &role
 	}
-
 	dns := app.DNSName
 	if dns != "" {
 		dnsName = &dns
 	}
-
 	return
 }
