@@ -18,17 +18,15 @@ import (
 
 func Test_convertSidecar(t *testing.T) {
 	mockImage := aws.String("mockImage")
-	mockWorkloadName := "frontend"
 	mockMap := map[string]string{"foo": "bar"}
 	mockCredsParam := aws.String("mockCredsParam")
-	circularDependencyErr := fmt.Errorf("circular container dependency chain includes the following containers: ")
 	testCases := map[string]struct {
 		inPort            *string
 		inEssential       bool
 		inLabels          map[string]string
 		inDependsOn       map[string]string
-		inImg             manifest.Image
 		inImageOverride   manifest.ImageOverride
+		inHealthCheck     manifest.ContainerHealthCheck
 		circDepContainers []string
 
 		wanted    *template.SidecarOpts
@@ -68,46 +66,7 @@ func Test_convertSidecar(t *testing.T) {
 				Essential:  aws.Bool(true),
 			},
 		},
-		"invalid container dependency due to circularly depending on itself": {
-			inPort:      aws.String("2000"),
-			inEssential: true,
-			inDependsOn: map[string]string{
-				"foo": "start",
-			},
-
-			wantedErr: fmt.Errorf("container foo cannot depend on itself"),
-		},
-		"invalid container dependency due to circularly depending on another container": {
-			inPort:      aws.String("2000"),
-			inEssential: true,
-			inDependsOn: map[string]string{
-				"frontend": "start",
-			},
-			inImg: manifest.Image{
-				DependsOn: map[string]string{
-					"foo": "start",
-				},
-			},
-			wantedErr:         circularDependencyErr,
-			circDepContainers: []string{"frontend", "foo"},
-		},
-		"invalid container dependency status": {
-			inPort:      aws.String("2000"),
-			inEssential: true,
-			inDependsOn: map[string]string{
-				"frontend": "never",
-			},
-			wantedErr: errInvalidDependsOnStatus,
-		},
-		"invalid essential container dependency status": {
-			inPort:      aws.String("2000"),
-			inEssential: true,
-			inDependsOn: map[string]string{
-				"frontend": "complete",
-			},
-			wantedErr: errEssentialContainerStatus,
-		},
-		"good essential container dependencies": {
+		"good container dependencies": {
 			inPort:      aws.String("2000"),
 			inEssential: true,
 			inDependsOn: map[string]string{
@@ -127,24 +86,6 @@ func Test_convertSidecar(t *testing.T) {
 				},
 			},
 		},
-		"good nonessential container dependencies": {
-			inEssential: false,
-			inDependsOn: map[string]string{
-				"frontend": "start",
-			},
-
-			wanted: &template.SidecarOpts{
-				Name:       aws.String("foo"),
-				CredsParam: mockCredsParam,
-				Image:      mockImage,
-				Secrets:    mockMap,
-				Variables:  mockMap,
-				Essential:  aws.Bool(false),
-				DependsOn: map[string]string{
-					"frontend": "START",
-				},
-			},
-		},
 		"specify essential as false": {
 			inPort:      aws.String("2000"),
 			inEssential: false,
@@ -179,7 +120,7 @@ func Test_convertSidecar(t *testing.T) {
 		},
 		"specify entrypoint as a string": {
 			inImageOverride: manifest.ImageOverride{
-				EntryPoint: &manifest.EntryPointOverride{String: aws.String("bin")},
+				EntryPoint: manifest.EntryPointOverride{String: aws.String("bin")},
 			},
 
 			wanted: &template.SidecarOpts{
@@ -195,7 +136,7 @@ func Test_convertSidecar(t *testing.T) {
 		},
 		"specify entrypoint as a string slice": {
 			inImageOverride: manifest.ImageOverride{
-				EntryPoint: &manifest.EntryPointOverride{StringSlice: []string{"bin", "arg"}},
+				EntryPoint: manifest.EntryPointOverride{StringSlice: []string{"bin", "arg"}},
 			},
 
 			wanted: &template.SidecarOpts{
@@ -211,7 +152,7 @@ func Test_convertSidecar(t *testing.T) {
 		},
 		"specify command as a string": {
 			inImageOverride: manifest.ImageOverride{
-				Command: &manifest.CommandOverride{String: aws.String("arg")},
+				Command: manifest.CommandOverride{String: aws.String("arg")},
 			},
 
 			wanted: &template.SidecarOpts{
@@ -227,7 +168,7 @@ func Test_convertSidecar(t *testing.T) {
 		},
 		"specify command as a string slice": {
 			inImageOverride: manifest.ImageOverride{
-				Command: &manifest.CommandOverride{StringSlice: []string{"arg1", "arg2"}},
+				Command: manifest.CommandOverride{StringSlice: []string{"arg1", "arg2"}},
 			},
 
 			wanted: &template.SidecarOpts{
@@ -241,6 +182,27 @@ func Test_convertSidecar(t *testing.T) {
 				Command:    []string{"arg1", "arg2"},
 			},
 		},
+		"with health check": {
+			inHealthCheck: manifest.ContainerHealthCheck{
+				Command: []string{"foo", "bar"},
+			},
+
+			wanted: &template.SidecarOpts{
+				Name:       aws.String("foo"),
+				CredsParam: mockCredsParam,
+				Image:      mockImage,
+				Secrets:    mockMap,
+				Variables:  mockMap,
+				Essential:  aws.Bool(false),
+				HealthCheck: &template.ContainerHealthCheck{
+					Command:     []string{"foo", "bar"},
+					Interval:    aws.Int64(10),
+					Retries:     aws.Int64(2),
+					StartPeriod: aws.Int64(0),
+					Timeout:     aws.Int64(5),
+				},
+			},
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -255,20 +217,12 @@ func Test_convertSidecar(t *testing.T) {
 					DockerLabels:  tc.inLabels,
 					DependsOn:     tc.inDependsOn,
 					ImageOverride: tc.inImageOverride,
+					HealthCheck:   tc.inHealthCheck,
 				},
 			}
-			got, err := convertSidecar(convertSidecarOpts{
-				sidecarConfig: sidecar,
-				imageConfig:   &tc.inImg,
-				workloadName:  mockWorkloadName,
-			})
+			got, err := convertSidecar(sidecar)
 
-			if tc.wantedErr == circularDependencyErr {
-				require.Contains(t, err.Error(), circularDependencyErr.Error())
-				for _, container := range tc.circDepContainers {
-					require.Contains(t, err.Error(), container)
-				}
-			} else if tc.wantedErr != nil {
+			if tc.wantedErr != nil {
 				require.EqualError(t, err, tc.wantedErr.Error())
 			} else {
 				require.NoError(t, err)
@@ -280,21 +234,14 @@ func Test_convertSidecar(t *testing.T) {
 
 func Test_convertAdvancedCount(t *testing.T) {
 	mockRange := manifest.IntRangeBand("1-10")
+	mockPerc := manifest.Percentage(70)
 	testCases := map[string]struct {
-		input       *manifest.AdvancedCount
+		input       manifest.AdvancedCount
 		expected    *template.AdvancedCount
 		expectedErr error
 	}{
-		"returns nil if nil": {
-			input:    nil,
-			expected: nil,
-		},
-		"returns nil if empty": {
-			input:    &manifest.AdvancedCount{},
-			expected: nil,
-		},
 		"success with spot count": {
-			input: &manifest.AdvancedCount{
+			input: manifest.AdvancedCount{
 				Spot: aws.Int(1),
 			},
 			expected: &template.AdvancedCount{
@@ -308,11 +255,11 @@ func Test_convertAdvancedCount(t *testing.T) {
 			},
 		},
 		"success with fargate autoscaling": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					Value: &mockRange,
 				},
-				CPU: aws.Int(70),
+				CPU: &mockPerc,
 			},
 			expected: &template.AdvancedCount{
 				Autoscaling: &template.AutoscalingOpts{
@@ -323,15 +270,15 @@ func Test_convertAdvancedCount(t *testing.T) {
 			},
 		},
 		"success with spot autoscaling": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					RangeConfig: manifest.RangeConfig{
 						Min:      aws.Int(2),
 						Max:      aws.Int(20),
 						SpotFrom: aws.Int(5),
 					},
 				},
-				CPU: aws.Int(70),
+				CPU: &mockPerc,
 			},
 			expected: &template.AdvancedCount{
 				Autoscaling: &template.AutoscalingOpts{
@@ -372,12 +319,11 @@ func Test_convertCapacityProviders(t *testing.T) {
 	minCapacity := 1
 	spotFrom := 3
 	testCases := map[string]struct {
-		input       *manifest.AdvancedCount
-		expected    []*template.CapacityProviderStrategy
-		expectedErr error
+		input    manifest.AdvancedCount
+		expected []*template.CapacityProviderStrategy
 	}{
 		"with spot as desiredCount": {
-			input: &manifest.AdvancedCount{
+			input: manifest.AdvancedCount{
 				Spot: aws.Int(3),
 			},
 
@@ -389,8 +335,8 @@ func Test_convertCapacityProviders(t *testing.T) {
 			},
 		},
 		"with scaling only on spot": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					RangeConfig: manifest.RangeConfig{
 						Min:      aws.Int(minCapacity),
 						Max:      aws.Int(10),
@@ -407,8 +353,8 @@ func Test_convertCapacityProviders(t *testing.T) {
 			},
 		},
 		"with scaling into spot": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					RangeConfig: manifest.RangeConfig{
 						Min:      aws.Int(minCapacity),
 						Max:      aws.Int(10),
@@ -430,52 +376,44 @@ func Test_convertCapacityProviders(t *testing.T) {
 			},
 		},
 		"returns nil if no spot config specified": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					Value: &mockRange,
 				},
 			},
 			expected: nil,
 		},
-		"errors if spot specified with range": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
-					Value: &mockRange,
-				},
-				Spot: aws.Int(3),
-			},
-			expectedErr: errInvalidSpotConfig,
-		},
 	}
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			actual, err := convertCapacityProviders(tc.input)
-
-			if tc.expectedErr != nil {
-				require.EqualError(t, err, tc.expectedErr.Error())
-			} else {
-				require.NoError(t, err)
-				require.Equal(t, tc.expected, actual)
-			}
+			actual := convertCapacityProviders(tc.input)
+			require.Equal(t, tc.expected, actual)
 		})
 	}
 }
 
 func Test_convertAutoscaling(t *testing.T) {
-	mockRange := manifest.IntRangeBand("1-100")
-	badRange := manifest.IntRangeBand("badRange")
-	mockRequests := 1000
-	mockResponseTime := 512 * time.Millisecond
+	var (
+		mockRange        = manifest.IntRangeBand("1-100")
+		badRange         = manifest.IntRangeBand("badRange")
+		mockRequests     = 1000
+		mockResponseTime = 512 * time.Millisecond
+		mockCPU          = manifest.Percentage(70)
+		mockMem          = manifest.Percentage(80)
+	)
+
+	testAcceptableLatency := 10 * time.Minute
+	testAvgProcessingTime := 250 * time.Millisecond
 	testCases := map[string]struct {
-		input *manifest.AdvancedCount
+		input manifest.AdvancedCount
 
 		wanted    *template.AutoscalingOpts
 		wantedErr error
 	}{
 		"invalid range": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					Value: &badRange,
 				},
 			},
@@ -483,12 +421,12 @@ func Test_convertAutoscaling(t *testing.T) {
 			wantedErr: fmt.Errorf("invalid range value badRange. Should be in format of ${min}-${max}"),
 		},
 		"success": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					Value: &mockRange,
 				},
-				CPU:          aws.Int(70),
-				Memory:       aws.Int(80),
+				CPU:          &mockCPU,
+				Memory:       &mockMem,
 				Requests:     aws.Int(mockRequests),
 				ResponseTime: &mockResponseTime,
 			},
@@ -503,16 +441,16 @@ func Test_convertAutoscaling(t *testing.T) {
 			},
 		},
 		"success with range subfields": {
-			input: &manifest.AdvancedCount{
-				Range: &manifest.Range{
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
 					RangeConfig: manifest.RangeConfig{
 						Min:      aws.Int(5),
 						Max:      aws.Int(10),
 						SpotFrom: aws.Int(5),
 					},
 				},
-				CPU:          aws.Int(70),
-				Memory:       aws.Int(80),
+				CPU:          &mockCPU,
+				Memory:       &mockMem,
 				Requests:     aws.Int(mockRequests),
 				ResponseTime: &mockResponseTime,
 			},
@@ -526,8 +464,30 @@ func Test_convertAutoscaling(t *testing.T) {
 				ResponseTime: aws.Float64(0.512),
 			},
 		},
+		"success with queue autoscaling": {
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
+					RangeConfig: manifest.RangeConfig{
+						Min:      aws.Int(5),
+						Max:      aws.Int(10),
+						SpotFrom: aws.Int(5),
+					},
+				},
+				QueueScaling: manifest.QueueScaling{
+					AcceptableLatency: &testAcceptableLatency,
+					AvgProcessingTime: &testAvgProcessingTime,
+				},
+			},
+			wanted: &template.AutoscalingOpts{
+				MaxCapacity: aws.Int(10),
+				MinCapacity: aws.Int(5),
+				QueueDelay: &template.AutoscalingQueueDelayOpts{
+					AcceptableBacklogPerTask: 2400,
+				},
+			},
+		},
 		"returns nil if spot specified": {
-			input: &manifest.AdvancedCount{
+			input: manifest.AdvancedCount{
 				Spot: aws.Int(5),
 			},
 			wanted: nil,
@@ -559,14 +519,6 @@ func Test_convertTaskDefOverrideRules(t *testing.T) {
 					Path:  "ContainerDefinitions[0].Ulimits[-].HardLimit",
 					Value: yaml.Node{},
 				},
-				{
-					Path:  "ContainerDefinitions[0].Name",
-					Value: yaml.Node{},
-				},
-				{
-					Path:  "Family",
-					Value: yaml.Node{},
-				},
 			},
 			wanted: []override.Rule{
 				{
@@ -738,12 +690,11 @@ func Test_convertManagedFSInfo(t *testing.T) {
 		inVolumes         map[string]*manifest.Volume
 		wantManagedConfig *template.ManagedVolumeCreationInfo
 		wantVolumes       map[string]manifest.Volume
-		wantErr           string
 	}{
 		"no managed config": {
 			inVolumes: map[string]*manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							FileSystemID: aws.String("fs-1234"),
 						},
@@ -756,7 +707,7 @@ func Test_convertManagedFSInfo(t *testing.T) {
 			wantManagedConfig: nil,
 			wantVolumes: map[string]manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							FileSystemID: aws.String("fs-1234"),
 						},
@@ -770,7 +721,7 @@ func Test_convertManagedFSInfo(t *testing.T) {
 		"with managed config": {
 			inVolumes: map[string]*manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Enabled: aws.Bool(true),
 					},
 					MountPointOpts: manifest.MountPointOpts{
@@ -789,7 +740,7 @@ func Test_convertManagedFSInfo(t *testing.T) {
 		"with custom UID": {
 			inVolumes: map[string]*manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							UID: aws.Uint32(10000),
 							GID: aws.Uint32(100000),
@@ -812,15 +763,10 @@ func Test_convertManagedFSInfo(t *testing.T) {
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
 			// WHEN
-			gotManaged, err := convertManagedFSInfo(aws.String("fe"), tc.inVolumes)
+			gotManaged := convertManagedFSInfo(aws.String("fe"), tc.inVolumes)
 
 			// THEN
-			if tc.wantErr != "" {
-				require.EqualError(t, err, tc.wantErr)
-			} else {
-				require.NoError(t, err)
-				require.Equal(t, tc.wantManagedConfig, gotManaged)
-			}
+			require.Equal(t, tc.wantManagedConfig, gotManaged)
 		})
 	}
 }
@@ -829,12 +775,11 @@ func Test_convertStorageOpts(t *testing.T) {
 		inVolumes   map[string]*manifest.Volume
 		inEphemeral *int
 		wantOpts    template.StorageOpts
-		wantErr     string
 	}{
 		"minimal configuration": {
 			inVolumes: map[string]*manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							FileSystemID: aws.String("fs-1234"),
 						},
@@ -876,7 +821,7 @@ func Test_convertStorageOpts(t *testing.T) {
 					MountPointOpts: manifest.MountPointOpts{
 						ContainerPath: aws.String("/var/scratch"),
 					},
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Enabled: aws.Bool(false),
 					},
 				},
@@ -896,26 +841,14 @@ func Test_convertStorageOpts(t *testing.T) {
 				},
 			},
 		},
-		"container path not specified": {
-			inVolumes: map[string]*manifest.Volume{
-				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
-						Advanced: manifest.EFSVolumeConfiguration{
-							FileSystemID: aws.String("fs-1234"),
-						},
-					},
-				},
-			},
-			wantErr: fmt.Sprintf("validate container configuration for volume wordpress: %s", errNoContainerPath.Error()),
-		},
 		"full specification with access point renders correctly": {
 			inVolumes: map[string]*manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							FileSystemID:  aws.String("fs-1234"),
 							RootDirectory: aws.String("/"),
-							AuthConfig: &manifest.AuthorizationConfig{
+							AuthConfig: manifest.AuthorizationConfig{
 								IAM:           aws.Bool(true),
 								AccessPointID: aws.String("ap-1234"),
 							},
@@ -958,11 +891,11 @@ func Test_convertStorageOpts(t *testing.T) {
 		"full specification without access point renders correctly": {
 			inVolumes: map[string]*manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							FileSystemID:  aws.String("fs-1234"),
 							RootDirectory: aws.String("/wordpress"),
-							AuthConfig: &manifest.AuthorizationConfig{
+							AuthConfig: manifest.AuthorizationConfig{
 								IAM: aws.Bool(true),
 							},
 						},
@@ -1002,7 +935,7 @@ func Test_convertStorageOpts(t *testing.T) {
 		"managed EFS": {
 			inVolumes: map[string]*manifest.Volume{
 				"efs": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Enabled: aws.Bool(true),
 					},
 					MountPointOpts: manifest.MountPointOpts{
@@ -1030,7 +963,7 @@ func Test_convertStorageOpts(t *testing.T) {
 		"managed EFS with config": {
 			inVolumes: map[string]*manifest.Volume{
 				"efs": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							UID: aws.Uint32(1000),
 							GID: aws.Uint32(10000),
@@ -1058,32 +991,10 @@ func Test_convertStorageOpts(t *testing.T) {
 				},
 			},
 		},
-		"error when multiple managed volumes specified": {
-			inVolumes: map[string]*manifest.Volume{
-				"efs": {
-					EFS: &manifest.EFSConfigOrBool{
-						Enabled: aws.Bool(true),
-					},
-					MountPointOpts: manifest.MountPointOpts{
-						ContainerPath: aws.String("/var/www"),
-						ReadOnly:      aws.Bool(true),
-					},
-				},
-				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
-						Enabled: aws.Bool(true),
-					},
-					MountPointOpts: manifest.MountPointOpts{
-						ContainerPath: aws.String("/var/abc"),
-					},
-				},
-			},
-			wantErr: "cannot specify more than one managed volume per service",
-		},
 		"managed EFS and BYO": {
 			inVolumes: map[string]*manifest.Volume{
 				"efs": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Enabled: aws.Bool(true),
 					},
 					MountPointOpts: manifest.MountPointOpts{
@@ -1092,7 +1003,7 @@ func Test_convertStorageOpts(t *testing.T) {
 					},
 				},
 				"otherefs": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							FileSystemID: aws.String("fs-1234"),
 						},
@@ -1103,7 +1014,7 @@ func Test_convertStorageOpts(t *testing.T) {
 					},
 				},
 				"ephemeral": {
-					EFS: nil,
+					EFS: manifest.EFSConfigOrBool{},
 					MountPointOpts: manifest.MountPointOpts{
 						ContainerPath: aws.String("/var/ephemeral"),
 						ReadOnly:      aws.Bool(false),
@@ -1158,7 +1069,7 @@ func Test_convertStorageOpts(t *testing.T) {
 		"efs specified with just ID": {
 			inVolumes: map[string]*manifest.Volume{
 				"wordpress": {
-					EFS: &manifest.EFSConfigOrBool{
+					EFS: manifest.EFSConfigOrBool{
 						Advanced: manifest.EFSVolumeConfiguration{
 							FileSystemID: aws.String("fs-1234"),
 						},
@@ -1205,18 +1116,13 @@ func Test_convertStorageOpts(t *testing.T) {
 			}
 
 			// WHEN
-			got, err := convertStorageOpts(aws.String("fe"), &s)
+			got := convertStorageOpts(aws.String("fe"), s)
 
 			// THEN
-			if tc.wantErr != "" {
-				require.EqualError(t, err, tc.wantErr)
-			} else {
-				require.NoError(t, err)
-				require.ElementsMatch(t, tc.wantOpts.EFSPerms, got.EFSPerms)
-				require.ElementsMatch(t, tc.wantOpts.MountPoints, got.MountPoints)
-				require.ElementsMatch(t, tc.wantOpts.Volumes, got.Volumes)
-				require.Equal(t, tc.wantOpts.ManagedVolumeInfo, got.ManagedVolumeInfo)
-			}
+			require.ElementsMatch(t, tc.wantOpts.EFSPerms, got.EFSPerms)
+			require.ElementsMatch(t, tc.wantOpts.MountPoints, got.MountPoints)
+			require.ElementsMatch(t, tc.wantOpts.Volumes, got.Volumes)
+			require.Equal(t, tc.wantOpts.ManagedVolumeInfo, got.ManagedVolumeInfo)
 		})
 	}
 }
@@ -1259,7 +1165,6 @@ func Test_convertExecuteCommand(t *testing.T) {
 func Test_convertSidecarMountPoints(t *testing.T) {
 	testCases := map[string]struct {
 		inMountPoints  []manifest.SidecarMountPoint
-		wantErr        string
 		wantMountPoint []*template.MountPoint
 	}{
 		"fully specified": {
@@ -1297,51 +1202,15 @@ func Test_convertSidecarMountPoints(t *testing.T) {
 				},
 			},
 		},
-		"error when source not specified": {
-			inMountPoints: []manifest.SidecarMountPoint{
-				{
-					MountPointOpts: manifest.MountPointOpts{
-						ContainerPath: aws.String("/var/www/wp-content"),
-						ReadOnly:      aws.Bool(false),
-					},
-				},
-			},
-			wantErr: errNoSourceVolume.Error(),
-		},
-		"error when path not specified": {
-			inMountPoints: []manifest.SidecarMountPoint{
-				{
-					SourceVolume: aws.String("wordpress"),
-					MountPointOpts: manifest.MountPointOpts{
-						ReadOnly: aws.Bool(false),
-					},
-				},
-			},
-			wantErr: errNoContainerPath.Error(),
-		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			err := validateSidecarMountPoints(tc.inMountPoints)
-			if tc.wantErr != "" {
-				require.EqualError(t, err, tc.wantErr)
-			} else {
-				require.NoError(t, err)
-				got := convertSidecarMountPoints(tc.inMountPoints)
-				require.Equal(t, tc.wantMountPoint, got)
-			}
+			got := convertSidecarMountPoints(tc.inMountPoints)
+			require.Equal(t, tc.wantMountPoint, got)
 		})
 	}
 }
 
-func Test_validatePaths(t *testing.T) {
-	t.Run("containerPath should be properly validated", func(t *testing.T) {
-		require.NoError(t, validateContainerPath("/abc/90_"), "contains underscore")
-		require.EqualError(t, validateContainerPath("/aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"), "path must be less than 242 bytes in length", "too long")
-		require.EqualError(t, validateContainerPath("/etc /bin/sh cat `i'm evil` > /dev/null"), "paths can only contain the characters a-zA-Z0-9.-_/", "invalid characters disallowed")
-	})
-}
-
 func Test_convertEphemeral(t *testing.T) {
 	testCases := map[string]struct {
 		inEphemeral *int
@@ -1353,14 +1222,6 @@ func Test_convertEphemeral(t *testing.T) {
 			inEphemeral: nil,
 			wanted:      nil,
 		},
-		"ephemeral errors when size is too big": {
-			inEphemeral: aws.Int(25000),
-			wantedError: errEphemeralBadSize,
-		},
-		"ephemeral errors when size is too small": {
-			inEphemeral: aws.Int(10),
-			wantedError: errEphemeralBadSize,
-		},
 		"ephemeral specified correctly": {
 			inEphemeral: aws.Int(100),
 			wanted:      aws.Int(100),
@@ -1372,128 +1233,8 @@ func Test_convertEphemeral(t *testing.T) {
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			got, err := convertEphemeral(tc.inEphemeral)
-			if tc.wantedError != nil {
-				require.EqualError(t, err, tc.wantedError.Error())
-			} else {
-				require.Equal(t, got, tc.wanted)
-			}
-		})
-	}
-}
-
-func Test_convertImageDependsOn(t *testing.T) {
-	mockWorkloadName := "frontend"
-	circularDependencyErr := fmt.Errorf("circular container dependency chain includes the following containers: ")
-	testCases := map[string]struct {
-		inImage           *manifest.Image
-		inSidecars        map[string]*manifest.SidecarConfig
-		circDepContainers []string
-
-		wanted      map[string]string
-		wantedError error
-	}{
-		"no container dependencies": {
-			inImage: &manifest.Image{},
-			wanted:  nil,
-		},
-		"invalid container dependency due to circular dependency on itself": {
-			inImage: &manifest.Image{
-				DependsOn: map[string]string{
-					"frontend": "start",
-				},
-			},
-			wantedError: fmt.Errorf("container frontend cannot depend on itself"),
-		},
-		"invalid container dependency due to circular dependency on a sidecar": {
-			inImage: &manifest.Image{
-				DependsOn: map[string]string{
-					"sidecar": "start",
-				},
-			},
-			inSidecars: map[string]*manifest.SidecarConfig{
-				"sidecar": {
-					DependsOn: map[string]string{
-						"sidecar2": "start",
-					},
-				},
-				"sidecar2": {
-					DependsOn: map[string]string{
-						"frontend": "start",
-					},
-				},
-			},
-			wantedError:       circularDependencyErr,
-			circDepContainers: []string{"frontend", "sidecar", "sidecar2"},
-		},
-		"invalid container dependency due to status": {
-			inImage: &manifest.Image{
-				DependsOn: map[string]string{
-					"sidecar": "end",
-				},
-			},
-			inSidecars: map[string]*manifest.SidecarConfig{
-				"sidecar": {
-					Essential: aws.Bool(false),
-				},
-			},
-			wantedError: errInvalidSidecarDependsOnStatus,
-		},
-		"invalid implied essential container depdendency": {
-			inImage: &manifest.Image{
-				DependsOn: map[string]string{
-					"sidecar": "complete",
-				},
-			},
-			inSidecars: map[string]*manifest.SidecarConfig{
-				"sidecar": {},
-			},
-			wantedError: errEssentialSidecarStatus,
-		},
-		"invalid set essential container depdendency": {
-			inImage: &manifest.Image{
-				DependsOn: map[string]string{
-					"sidecar": "complete",
-				},
-			},
-			inSidecars: map[string]*manifest.SidecarConfig{
-				"sidecar": {
-					Essential: aws.Bool(true),
-				},
-			},
-			wantedError: errEssentialSidecarStatus,
-		},
-		"good essential container dependency": {
-			inImage: &manifest.Image{
-				DependsOn: map[string]string{
-					"sidecar": "start",
-				},
-			},
-			inSidecars: map[string]*manifest.SidecarConfig{
-				"sidecar": {},
-			},
-			wanted: map[string]string{
-				"sidecar": "START",
-			},
-		},
-	}
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			got, err := convertImageDependsOn(convertSidecarOpts{
-				sidecarConfig: tc.inSidecars,
-				imageConfig:   tc.inImage,
-				workloadName:  mockWorkloadName,
-			})
-			if tc.wantedError == circularDependencyErr {
-				require.Contains(t, err.Error(), circularDependencyErr.Error())
-				for _, container := range tc.circDepContainers {
-					require.Contains(t, err.Error(), container)
-				}
-			} else if tc.wantedError != nil {
-				require.EqualError(t, err, tc.wantedError.Error())
-			} else {
-				require.Equal(t, got, tc.wanted)
-			}
+			got := convertEphemeral(tc.inEphemeral)
+			require.Equal(t, got, tc.wanted)
 		})
 	}
 }
@@ -1519,15 +1260,14 @@ func Test_convertPublish(t *testing.T) {
 			inTopics: []manifest.Topic{},
 			wanted:   nil,
 		},
-		"publish with no topic names": {
-			inTopics:    []manifest.Topic{{}},
-			wantedError: errMissingPublishTopicField,
-		},
-		"publish with no workers": {
+		"valid publish": {
 			inTopics: []manifest.Topic{
 				{
 					Name: aws.String("topic1"),
 				},
+				{
+					Name: aws.String("topic2"),
+				},
 			},
 			wanted: &template.PublishOpts{
 				Topics: []*template.Topic{
@@ -1540,49 +1280,19 @@ func Test_convertPublish(t *testing.T) {
 						Env:       env,
 						Svc:       svc,
 					},
-				},
-			},
-		},
-		"publish with workers": {
-			inTopics: []manifest.Topic{
-				{
-					Name:           aws.String("topic1"),
-					AllowedWorkers: []string{"worker1"},
-				},
-			},
-			wanted: &template.PublishOpts{
-				Topics: []*template.Topic{
 					{
-						Name:           aws.String("topic1"),
-						AllowedWorkers: []string{"worker1"},
-						AccountID:      accountId,
-						Partition:      partition,
-						Region:         region,
-						App:            app,
-						Env:            env,
-						Svc:            svc,
+
+						Name:      aws.String("topic2"),
+						AccountID: accountId,
+						Partition: partition,
+						Region:    region,
+						App:       app,
+						Env:       env,
+						Svc:       svc,
 					},
 				},
 			},
 		},
-		"invalid worker name": {
-			inTopics: []manifest.Topic{
-				{
-					Name:           aws.String("topic1"),
-					AllowedWorkers: []string{"worker1~~@#$"},
-				},
-			},
-			wantedError: fmt.Errorf("worker name `worker1~~@#$` is invalid: %s", errSvcNameBadFormat),
-		},
-		"invalid topic name": {
-			inTopics: []manifest.Topic{
-				{
-					Name:           aws.String("topic1~~@#$"),
-					AllowedWorkers: []string{"worker1"},
-				},
-			},
-			wantedError: errInvalidPubSubTopicName,
-		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -1597,45 +1307,34 @@ func Test_convertPublish(t *testing.T) {
 }
 
 func Test_convertSubscribe(t *testing.T) {
-	validTopics := []string{"arn:aws:sns:us-west-2:123456789123:app-env-svc-name", "arn:aws:sns:us-west-2:123456789123:app-env-svc-name2"}
 	accountId := "123456789123"
 	region := "us-west-2"
 	app := "app"
 	env := "env"
 	svc := "svc"
 	duration111Seconds := 111 * time.Second
-	duration5Days := 120 * time.Hour
 	testCases := map[string]struct {
-		inSubscribe *manifest.SubscribeConfig
+		inSubscribe manifest.SubscribeConfig
 
-		wanted      *template.SubscribeOpts
-		wantedError error
+		wanted *template.SubscribeOpts
 	}{
 		"empty subscription": {
-			inSubscribe: &manifest.SubscribeConfig{},
+			inSubscribe: manifest.SubscribeConfig{},
 			wanted:      nil,
 		},
-		"subscription with empty topic subscriptions": {
-			inSubscribe: &manifest.SubscribeConfig{
-				Topics: []manifest.TopicSubscription{
-					{},
-				},
-			},
-			wantedError: fmt.Errorf(`invalid topic subscription "": %w`, errMissingPublishTopicField),
-		},
 		"valid subscribe": {
-			inSubscribe: &manifest.SubscribeConfig{
+			inSubscribe: manifest.SubscribeConfig{
 				Topics: []manifest.TopicSubscription{
 					{
-						Name:    "name",
-						Service: "svc",
+						Name:    aws.String("name"),
+						Service: aws.String("svc"),
 					},
 				},
-				Queue: &manifest.SQSQueue{
+				Queue: manifest.SQSQueue{
 					Retention: &duration111Seconds,
 					Delay:     &duration111Seconds,
 					Timeout:   &duration111Seconds,
-					DeadLetter: &manifest.DeadLetterQueue{
+					DeadLetter: manifest.DeadLetterQueue{
 						Tries: aws.Uint16(35),
 					},
 				},
@@ -1658,70 +1357,35 @@ func Test_convertSubscribe(t *testing.T) {
 			},
 		},
 		"valid subscribe with minimal queue": {
-			inSubscribe: &manifest.SubscribeConfig{
+			inSubscribe: manifest.SubscribeConfig{
 				Topics: []manifest.TopicSubscription{
 					{
-						Name:    "name",
-						Service: "svc",
+						Name:    aws.String("name"),
+						Service: aws.String("svc"),
+						Queue: manifest.SQSQueueOrBool{
+							Enabled: aws.Bool(true),
+						},
 					},
 				},
-				Queue: &manifest.SQSQueue{},
+				Queue: manifest.SQSQueue{},
 			},
 			wanted: &template.SubscribeOpts{
 				Topics: []*template.TopicSubscription{
 					{
 						Name:    aws.String("name"),
 						Service: aws.String("svc"),
+						Queue:   &template.SQSQueue{},
 					},
 				},
-				Queue: &template.SQSQueue{},
+				Queue: nil,
 			},
 		},
-		"invalid topic name": {
-			inSubscribe: &manifest.SubscribeConfig{
-				Topics: []manifest.TopicSubscription{
-					{
-						Name:    "t@p!c1~",
-						Service: "service1",
-					},
-				},
-			},
-			wantedError: fmt.Errorf(`invalid topic subscription "t@p!c1~": %w`, errInvalidPubSubTopicName),
-		},
-		"invalid service name": {
-			inSubscribe: &manifest.SubscribeConfig{
-				Topics: []manifest.TopicSubscription{
-					{
-						Name:    "topic1",
-						Service: "s#rv!ce1~",
-					},
-				},
-			},
-			wantedError: fmt.Errorf(`invalid topic subscription "topic1": %w`, errSvcNameBadFormat),
-		},
-		"subscribe queue delay invalid": {
-			inSubscribe: &manifest.SubscribeConfig{
-				Topics: []manifest.TopicSubscription{
-					{
-						Name:    "name",
-						Service: "svc",
-					},
-				},
-				Queue: &manifest.SQSQueue{
-					Delay: &duration5Days,
-				},
-			},
-			wantedError: fmt.Errorf("`delay` must be between 0s and 15m0s"),
-		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			got, err := convertSubscribe(tc.inSubscribe, validTopics, accountId, region, app, env, svc)
-			if tc.wantedError != nil {
-				require.EqualError(t, err, tc.wantedError.Error())
-			} else {
-				require.Equal(t, tc.wanted, got)
-			}
+			got, err := convertSubscribe(tc.inSubscribe, accountId, region, app, env, svc)
+			require.Equal(t, tc.wanted, got)
+			require.NoError(t, err)
 		})
 	}
 }
