@@ -14,6 +14,11 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/template/override"
 )
 
+// Template rendering configuration.
+const (
+	backlogCalculatorLambdaPath = "custom-resources/backlog-per-task-calculator.js"
+)
+
 type workerSvcReadParser interface {
 	template.ReadParser
 	ParseWorkerService(template.WorkloadOpts) (*template.Content, error)
@@ -24,8 +29,7 @@ type WorkerService struct {
 	*ecsWkld
 	manifest *manifest.WorkerService
 
-	allowedTopics []string
-	parser        workerSvcReadParser
+	parser workerSvcReadParser
 }
 
 // NewWorkerService creates a new WorkerService stack from a manifest file.
@@ -42,10 +46,11 @@ func NewWorkerService(mft *manifest.WorkerService, env, app string, rc RuntimeCo
 				env:    env,
 				app:    app,
 				rc:     rc,
-				image:  mft.ImageConfig,
+				image:  mft.ImageConfig.Image,
 				parser: parser,
 				addons: addons,
 			},
+			logRetention:        mft.Logging.Retention,
 			tc:                  mft.TaskConfig,
 			taskDefOverrideFunc: override.CloudFormationTemplate,
 		},
@@ -59,31 +64,25 @@ func NewWorkerService(mft *manifest.WorkerService, env, app string, rc RuntimeCo
 func (s *WorkerService) Template() (string, error) {
 	desiredCountLambda, err := s.parser.Read(desiredCountGeneratorPath)
 	if err != nil {
-		return "", fmt.Errorf("read desired count lambda: %w", err)
+		return "", fmt.Errorf("read desired count lambda function source code: %w", err)
 	}
 	envControllerLambda, err := s.parser.Read(envControllerPath)
 	if err != nil {
-		return "", fmt.Errorf("read env controller lambda: %w", err)
+		return "", fmt.Errorf("read env controller lambda function source code: %w", err)
+	}
+	backlogPerTaskLambda, err := s.parser.Read(backlogCalculatorLambdaPath)
+	if err != nil {
+		return "", fmt.Errorf("read backlog-per-task-calculator lambda function source code: %w", err)
 	}
 	outputs, err := s.addonsOutputs()
 	if err != nil {
 		return "", err
 	}
-	convSidecarOpts := convertSidecarOpts{
-		sidecarConfig: s.manifest.Sidecars,
-		imageConfig:   &s.manifest.ImageConfig.Image,
-		workloadName:  aws.StringValue(s.manifest.Name),
-	}
-	sidecars, err := convertSidecar(convSidecarOpts)
+	sidecars, err := convertSidecar(s.manifest.Sidecars)
 	if err != nil {
 		return "", fmt.Errorf("convert the sidecar configuration for service %s: %w", s.name, err)
 	}
-	dependencies, err := convertImageDependsOn(convSidecarOpts)
-	if err != nil {
-		return "", fmt.Errorf("convert the container dependency for service %s: %w", s.name, err)
-	}
-
-	advancedCount, err := convertAdvancedCount(&s.manifest.Count.AdvancedCount)
+	advancedCount, err := convertAdvancedCount(s.manifest.Count.AdvancedCount)
 	if err != nil {
 		return "", fmt.Errorf("convert the advanced count configuration for service %s: %w", s.name, err)
 	}
@@ -97,10 +96,6 @@ func (s *WorkerService) Template() (string, error) {
 		desiredCountOnSpot = advancedCount.Spot
 		capacityProviders = advancedCount.Cps
 	}
-	storage, err := convertStorageOpts(s.manifest.Name, s.manifest.Storage)
-	if err != nil {
-		return "", fmt.Errorf("convert storage options for service %s: %w", s.name, err)
-	}
 	entrypoint, err := convertEntryPoint(s.manifest.EntryPoint)
 	if err != nil {
 		return "", err
@@ -109,33 +104,34 @@ func (s *WorkerService) Template() (string, error) {
 	if err != nil {
 		return "", err
 	}
-	subscribe, err := convertSubscribe(s.manifest.Subscribe, s.allowedTopics, s.rc.AccountID, s.rc.Region, s.app, s.env, s.name)
+	subscribe, err := convertSubscribe(s.manifest.Subscribe, s.rc.AccountID, s.rc.Region, s.app, s.env, s.name)
 	if err != nil {
 		return "", err
 	}
 	content, err := s.parser.ParseWorkerService(template.WorkloadOpts{
-		Variables:                s.manifest.WorkerServiceConfig.Variables,
-		Secrets:                  s.manifest.WorkerServiceConfig.Secrets,
-		NestedStack:              outputs,
-		Sidecars:                 sidecars,
-		Autoscaling:              autoscaling,
-		CapacityProviders:        capacityProviders,
-		DesiredCountOnSpot:       desiredCountOnSpot,
-		ExecuteCommand:           convertExecuteCommand(&s.manifest.ExecuteCommand),
-		WorkloadType:             manifest.WorkerServiceType,
-		HealthCheck:              s.manifest.WorkerServiceConfig.ImageConfig.HealthCheckOpts(),
-		LogConfig:                convertLogging(s.manifest.Logging),
-		DockerLabels:             s.manifest.ImageConfig.DockerLabels,
-		DesiredCountLambda:       desiredCountLambda.String(),
-		EnvControllerLambda:      envControllerLambda.String(),
-		Storage:                  storage,
-		Network:                  convertNetworkConfig(s.manifest.Network),
-		EntryPoint:               entrypoint,
-		Command:                  command,
-		DependsOn:                dependencies,
-		CredentialsParameter:     aws.StringValue(s.manifest.ImageConfig.Credentials),
-		ServiceDiscoveryEndpoint: s.rc.ServiceDiscoveryEndpoint,
-		Subscribe:                subscribe,
+		Variables:                      s.manifest.WorkerServiceConfig.Variables,
+		Secrets:                        s.manifest.WorkerServiceConfig.Secrets,
+		NestedStack:                    outputs,
+		Sidecars:                       sidecars,
+		Autoscaling:                    autoscaling,
+		CapacityProviders:              capacityProviders,
+		DesiredCountOnSpot:             desiredCountOnSpot,
+		ExecuteCommand:                 convertExecuteCommand(&s.manifest.ExecuteCommand),
+		WorkloadType:                   manifest.WorkerServiceType,
+		HealthCheck:                    convertContainerHealthCheck(s.manifest.WorkerServiceConfig.ImageConfig.HealthCheck),
+		LogConfig:                      convertLogging(s.manifest.Logging),
+		DockerLabels:                   s.manifest.ImageConfig.Image.DockerLabels,
+		DesiredCountLambda:             desiredCountLambda.String(),
+		EnvControllerLambda:            envControllerLambda.String(),
+		BacklogPerTaskCalculatorLambda: backlogPerTaskLambda.String(),
+		Storage:                        convertStorageOpts(s.manifest.Name, s.manifest.Storage),
+		Network:                        convertNetworkConfig(s.manifest.Network),
+		EntryPoint:                     entrypoint,
+		Command:                        command,
+		DependsOn:                      convertDependsOn(s.manifest.ImageConfig.Image.DependsOn),
+		CredentialsParameter:           aws.StringValue(s.manifest.ImageConfig.Image.Credentials),
+		ServiceDiscoveryEndpoint:       s.rc.ServiceDiscoveryEndpoint,
+		Subscribe:                      subscribe,
 	})
 	if err != nil {
 		return "", fmt.Errorf("parse worker service template: %w", err)
