@@ -6,7 +6,6 @@ package stack
 import (
 	"errors"
 	"fmt"
-	"regexp"
 	"strconv"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -55,16 +54,9 @@ const (
 	RDWkldHealthCheckUnhealthyThresholdParamKey = "HealthCheckUnhealthyThreshold"
 )
 
-// Matches alphanumeric characters and -._
-var pathRegexp = regexp.MustCompile(`^[a-zA-Z0-9\-\.\_/]+$`)
-
-// Max path length in EFS is 255 bytes.
-// https://docs.aws.amazon.com/efs/latest/ug/troubleshooting-efs-fileop-errors.html#filenametoolong
-const maxEFSPathLength = 255
-
-// In docker containers, max path length is 242.
-// https://github.com/moby/moby/issues/1413
-const maxDockerContainerPathLength = 242
+const (
+	ecsWkldLogRetentionDefault = 30
+)
 
 // RuntimeConfig represents configuration that's defined outside of the manifest file
 // that is needed to create a CloudFormation stack.
@@ -257,7 +249,8 @@ func envVarOutputNames(outputs []addon.Output) []string {
 
 type ecsWkld struct {
 	*wkld
-	tc manifest.TaskConfig
+	tc           manifest.TaskConfig
+	logRetention *int
 
 	// Overriden in unit tests.
 	taskDefOverrideFunc func(overrideRules []override.Rule, origTemp []byte) ([]byte, error)
@@ -273,6 +266,10 @@ func (w *ecsWkld) Parameters() ([]*cloudformation.Parameter, error) {
 	if err != nil {
 		return nil, err
 	}
+	logRetention := ecsWkldLogRetentionDefault
+	if w.logRetention != nil {
+		logRetention = aws.IntValue(w.logRetention)
+	}
 	return append(wkldParameters, []*cloudformation.Parameter{
 		{
 			ParameterKey:   aws.String(WorkloadTaskCPUParamKey),
@@ -288,7 +285,7 @@ func (w *ecsWkld) Parameters() ([]*cloudformation.Parameter, error) {
 		},
 		{
 			ParameterKey:   aws.String(WorkloadLogRetentionParamKey),
-			ParameterValue: aws.String("30"),
+			ParameterValue: aws.String(strconv.Itoa(logRetention)),
 		},
 	}...), nil
 }
