@@ -85,7 +85,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 			mockWriter: func(m *mocks.MockWorkspace) {
 				m.EXPECT().WriteJobManifest(gomock.Any(), "resizer").Do(func(m *manifest.ScheduledJob, _ string) {
 					require.Equal(t, *m.Workload.Type, manifest.ScheduledJobType)
-					require.Equal(t, *m.ImageConfig.Location, "mockImage")
+					require.Equal(t, *m.ImageConfig.Image.Location, "mockImage")
 				}).Return("/resizer/manifest.yml", nil)
 			},
 			mockstore: func(m *mocks.MockStore) {
@@ -363,7 +363,7 @@ func TestAppInitOpts_createLoadBalancedAppManifest(t *testing.T) {
 				require.NoError(t, err)
 				require.Equal(t, tc.inSvcName, aws.StringValue(manifest.Workload.Name))
 				require.Equal(t, tc.inSvcPort, aws.Uint16Value(manifest.ImageConfig.Port))
-				require.Contains(t, tc.inDockerfilePath, aws.StringValue(manifest.ImageConfig.Build.BuildArgs.Dockerfile))
+				require.Contains(t, tc.inDockerfilePath, aws.StringValue(manifest.ImageConfig.Image.Build.BuildArgs.Dockerfile))
 				require.Equal(t, tc.wantedPath, aws.StringValue(manifest.Path))
 			} else {
 				require.EqualError(t, err, tc.wantedErr.Error())
@@ -418,17 +418,16 @@ func TestAppInitOpts_createRequestDrivenWebServiceManifest(t *testing.T) {
 			require.Equal(t, tc.inSvcName, *manifest.Name)
 			require.Equal(t, tc.inSvcPort, *manifest.ImageConfig.Port)
 			if tc.inImage != "" {
-				require.Equal(t, tc.inImage, *manifest.ImageConfig.Location)
+				require.Equal(t, tc.inImage, *manifest.ImageConfig.Image.Location)
 			}
 			if tc.inDockerfilePath != "" {
-				require.Equal(t, tc.inDockerfilePath, *manifest.ImageConfig.Build.BuildArgs.Dockerfile)
+				require.Equal(t, tc.inDockerfilePath, *manifest.ImageConfig.Image.Build.BuildArgs.Dockerfile)
 			}
 		})
 	}
 }
 
 func TestWorkloadInitializer_Service(t *testing.T) {
-
 	var (
 		testInterval    = 10 * time.Second
 		testRetries     = 2
@@ -443,7 +442,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 		inDockerfilePath string
 		inAppName        string
 		inImage          string
-		inHealthCheck    *manifest.ContainerHealthCheck
+		inHealthCheck    manifest.ContainerHealthCheck
 		inTopics         []manifest.TopicSubscription
 
 		mockWriter      func(m *mocks.MockWorkspace)
@@ -589,8 +588,8 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "backend").
 					Do(func(m *manifest.BackendService, _ string) {
 						require.Equal(t, *m.Workload.Type, manifest.BackendServiceType)
-						require.Equal(t, *m.ImageConfig.Location, "mockImage")
-						require.Nil(t, m.ImageConfig.HealthCheck)
+						require.Equal(t, *m.ImageConfig.Image.Location, "mockImage")
+						require.Empty(t, m.ImageConfig.HealthCheck)
 					}).Return("/backend/manifest.yml", nil)
 			},
 			mockstore: func(m *mocks.MockStore) {
@@ -632,7 +631,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "backend").
 					Do(func(m *manifest.BackendService, _ string) {
 						require.Equal(t, *m.Workload.Type, manifest.BackendServiceType)
-						require.Nil(t, m.ImageConfig.HealthCheck)
+						require.Empty(t, m.ImageConfig.HealthCheck)
 					}).Return("/backend/manifest.yml", nil)
 			},
 			mockstore: func(m *mocks.MockStore) {
@@ -668,7 +667,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			inSvcName:        "backend",
 			inDockerfilePath: "backend/Dockerfile",
 			inSvcPort:        80,
-			inHealthCheck: &manifest.ContainerHealthCheck{
+			inHealthCheck: manifest.ContainerHealthCheck{
 				Interval:    &testInterval,
 				Retries:     &testRetries,
 				Timeout:     &testTimeout,
@@ -681,7 +680,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "backend").
 					Do(func(m *manifest.BackendService, _ string) {
 						require.Equal(t, *m.Workload.Type, manifest.BackendServiceType)
-						require.Equal(t, *m.ImageConfig.HealthCheck, manifest.ContainerHealthCheck{
+						require.Equal(t, m.ImageConfig.HealthCheck, manifest.ContainerHealthCheck{
 							Interval:    &testInterval,
 							Retries:     &testRetries,
 							Timeout:     &testTimeout,
@@ -723,8 +722,8 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			inSvcPort:        80,
 			inTopics: []manifest.TopicSubscription{
 				{
-					Name:    "theTopic",
-					Service: "publisher",
+					Name:    aws.String("theTopic"),
+					Service: aws.String("publisher"),
 				},
 			},
 
@@ -733,7 +732,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "worker").
 					Do(func(m *manifest.WorkerService, _ string) {
 						require.Equal(t, *m.Workload.Type, manifest.WorkerServiceType)
-						require.Nil(t, m.ImageConfig.HealthCheck)
+						require.Empty(t, m.ImageConfig.HealthCheck)
 					}).Return("/worker/manifest.yml", nil)
 			},
 			mockstore: func(m *mocks.MockStore) {
