@@ -33,8 +33,8 @@ func TestNewBackendSvc(t *testing.T) {
 					Type: aws.String(BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
 								Build: BuildArgsOrString{
 									BuildArgs: DockerBuildArgs{
@@ -54,9 +54,9 @@ func TestNewBackendSvc(t *testing.T) {
 							Enable: aws.Bool(false),
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement: stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement: &PublicSubnetPlacement,
 						},
 					},
 				},
@@ -68,7 +68,7 @@ func TestNewBackendSvc(t *testing.T) {
 					Name:  "subscribers",
 					Image: "mockImage",
 				},
-				HealthCheck: &ContainerHealthCheck{
+				HealthCheck: ContainerHealthCheck{
 					Command: []string{"CMD", "curl -f http://localhost:8080 || exit 1"},
 				},
 				Port: 8080,
@@ -79,14 +79,14 @@ func TestNewBackendSvc(t *testing.T) {
 					Type: aws.String(BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
 								Location: aws.String("mockImage"),
 							},
 							Port: aws.Uint16(8080),
 						},
-						HealthCheck: &ContainerHealthCheck{
+						HealthCheck: ContainerHealthCheck{
 							Command: []string{"CMD", "curl -f http://localhost:8080 || exit 1"},
 						},
 					},
@@ -100,9 +100,9 @@ func TestNewBackendSvc(t *testing.T) {
 							Enable: aws.Bool(false),
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement: stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement: &PublicSubnetPlacement,
 						},
 					},
 				},
@@ -146,7 +146,7 @@ func TestBackendSvc_MarshalBinary(t *testing.T) {
 					Name:  "subscribers",
 					Image: "flask-sample",
 				},
-				HealthCheck: &ContainerHealthCheck{
+				HealthCheck: ContainerHealthCheck{
 					Command:     []string{"CMD-SHELL", "curl -f http://localhost:8080 || exit 1"},
 					Interval:    durationp(6 * time.Second),
 					Retries:     aws.Int(0),
@@ -190,8 +190,8 @@ func TestBackendService_Port(t *testing.T) {
 		"returns the port value and sets ok to true if a port is exposed": {
 			mft: &BackendService{
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Port: uint16P(80),
 						},
 					},
@@ -226,7 +226,7 @@ func TestBackendService_Publish(t *testing.T) {
 		"returns the list of topics if manifest publishes notifications": {
 			mft: &BackendService{
 				BackendServiceConfig: BackendServiceConfig{
-					Publish: &PublishConfig{
+					PublishConfig: PublishConfig{
 						Topics: []Topic{
 							{
 								Name: stringP("hello"),
@@ -255,14 +255,15 @@ func TestBackendService_Publish(t *testing.T) {
 }
 
 func TestBackendSvc_ApplyEnv(t *testing.T) {
+	mockPercentage := Percentage(70)
 	mockBackendServiceWithNoEnvironments := BackendService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
 			Type: aws.String(BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
 						Build: BuildArgsOrString{
 							BuildArgs: DockerBuildArgs{
@@ -272,7 +273,7 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 					},
 					Port: aws.Uint16(8080),
 				},
-				HealthCheck: &ContainerHealthCheck{
+				HealthCheck: ContainerHealthCheck{
 					Command:     []string{"hello", "world"},
 					Interval:    durationp(1 * time.Second),
 					Retries:     aws.Int(100),
@@ -291,8 +292,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	}
 	mockBackendServiceWithNilEnvironment := BackendService{
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Port: aws.Uint16(80),
 				},
 			},
@@ -303,16 +304,16 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	}
 	mockBackendServiceWithMinimalOverride := BackendService{
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Port: aws.Uint16(80),
 				},
 			},
 		},
 		Environments: map[string]*BackendServiceConfig{
 			"test": {
-				ImageConfig: ImageWithPortAndHealthcheck{
-					ImageWithPort: ImageWithPort{
+				ImageConfig: ImageWithHealthcheckAndOptionalPort{
+					ImageWithOptionalPort: ImageWithOptionalPort{
 						Port: aws.Uint16(5000),
 					},
 				},
@@ -321,8 +322,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	}
 	mockBackendServiceWithAllOverride := BackendService{
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Port: aws.Uint16(80),
 					Image: Image{
 						DockerLabels: map[string]string{
@@ -345,7 +346,7 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 					Image: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
 				},
 			},
-			Logging: &Logging{
+			Logging: Logging{
 				Destination: map[string]string{
 					"Name":            "datadog",
 					"exclude-pattern": "*",
@@ -354,8 +355,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 		},
 		Environments: map[string]*BackendServiceConfig{
 			"test": {
-				ImageConfig: ImageWithPortAndHealthcheck{
-					ImageWithPort: ImageWithPort{
+				ImageConfig: ImageWithHealthcheckAndOptionalPort{
+					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
 							DockerLabels: map[string]string{
 								"com.amazonaws.ecs.copilot.description": "Overridden!",
@@ -366,7 +367,7 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 				TaskConfig: TaskConfig{
 					Count: Count{
 						AdvancedCount: AdvancedCount{
-							CPU: aws.Int(70),
+							CPU: &mockPercentage,
 						},
 					},
 					CPU: aws.Int(512),
@@ -379,7 +380,7 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 						CredsParam: aws.String("some arn"),
 					},
 				},
-				Logging: &Logging{
+				Logging: Logging{
 					Destination: map[string]string{
 						"include-pattern": "*",
 						"exclude-pattern": "fe/",
@@ -394,8 +395,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
 						Build: BuildArgsOrString{
 							BuildArgs: DockerBuildArgs{
@@ -408,8 +409,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 		},
 		Environments: map[string]*BackendServiceConfig{
 			"prod-iad": {
-				ImageConfig: ImageWithPortAndHealthcheck{
-					ImageWithPort: ImageWithPort{
+				ImageConfig: ImageWithHealthcheckAndOptionalPort{
+					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
 							Location: aws.String("env-override location"),
 						},
@@ -424,8 +425,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
 						Location: aws.String("original location"),
 					},
@@ -434,8 +435,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 		},
 		Environments: map[string]*BackendServiceConfig{
 			"prod-iad": {
-				ImageConfig: ImageWithPortAndHealthcheck{
-					ImageWithPort: ImageWithPort{
+				ImageConfig: ImageWithHealthcheckAndOptionalPort{
+					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
 							Location: aws.String("env-override location"),
 						},
@@ -450,8 +451,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
 						Build: BuildArgsOrString{
 							BuildArgs: DockerBuildArgs{
@@ -465,8 +466,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 		},
 		Environments: map[string]*BackendServiceConfig{
 			"prod-iad": {
-				ImageConfig: ImageWithPortAndHealthcheck{
-					ImageWithPort: ImageWithPort{
+				ImageConfig: ImageWithHealthcheckAndOptionalPort{
+					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
 							Build: BuildArgsOrString{
 								BuildString: aws.String("env overridden dockerfile"),
@@ -483,8 +484,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
-			ImageConfig: ImageWithPortAndHealthcheck{
-				ImageWithPort: ImageWithPort{
+			ImageConfig: ImageWithHealthcheckAndOptionalPort{
+				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
 						Location: aws.String("original location"),
 					},
@@ -493,8 +494,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 		},
 		Environments: map[string]*BackendServiceConfig{
 			"prod-iad": {
-				ImageConfig: ImageWithPortAndHealthcheck{
-					ImageWithPort: ImageWithPort{
+				ImageConfig: ImageWithHealthcheckAndOptionalPort{
+					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
 							Build: BuildArgsOrString{
 								BuildString: aws.String("env overridden dockerfile"),
@@ -532,8 +533,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 
 			wanted: &BackendService{
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Port: aws.Uint16(5000),
 						},
 					},
@@ -547,8 +548,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 
 			wanted: &BackendService{
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Port: aws.Uint16(80),
 							Image: Image{
 								DockerLabels: map[string]string{
@@ -562,7 +563,7 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 						Memory: aws.Int(256),
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								CPU: aws.Int(70),
+								CPU: &mockPercentage,
 							},
 						},
 						Variables: map[string]string{
@@ -576,7 +577,7 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 							CredsParam: aws.String("some arn"),
 						},
 					},
-					Logging: &Logging{
+					Logging: Logging{
 						Destination: map[string]string{
 							"Name":            "datadog",
 							"include-pattern": "*",
@@ -597,8 +598,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
 								Location: aws.String("env-override location"),
 							},
@@ -618,8 +619,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
 								Location: aws.String("env-override location"),
 							},
@@ -638,8 +639,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
 								Build: BuildArgsOrString{
 									BuildString: aws.String("env overridden dockerfile"),
@@ -660,8 +661,8 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
-					ImageConfig: ImageWithPortAndHealthcheck{
-						ImageWithPort: ImageWithPort{
+					ImageConfig: ImageWithHealthcheckAndOptionalPort{
+						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
 								Build: BuildArgsOrString{
 									BuildString: aws.String("env overridden dockerfile"),
@@ -689,6 +690,7 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 
 func TestBackendSvc_ApplyEnv_CountOverrides(t *testing.T) {
 	mockRange := IntRangeBand("1-10")
+	mockPercentage := Percentage(80)
 	testCases := map[string]struct {
 		svcCount Count
 		envCount Count
@@ -698,8 +700,8 @@ func TestBackendSvc_ApplyEnv_CountOverrides(t *testing.T) {
 		"empty env advanced count override": {
 			svcCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{Value: &mockRange},
-					CPU:   aws.Int(80),
+					Range: Range{Value: &mockRange},
+					CPU:   &mockPercentage,
 				},
 			},
 			envCount: Count{},
@@ -708,8 +710,8 @@ func TestBackendSvc_ApplyEnv_CountOverrides(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
-								CPU:   aws.Int(80),
+								Range: Range{Value: &mockRange},
+								CPU:   &mockPercentage,
 							},
 						},
 					},
@@ -749,7 +751,7 @@ func TestBackendSvc_ApplyEnv_CountOverrides(t *testing.T) {
 		"with range overriden by spot count": {
 			svcCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{Value: &mockRange},
+					Range: Range{Value: &mockRange},
 				},
 			},
 			envCount: Count{
@@ -772,12 +774,12 @@ func TestBackendSvc_ApplyEnv_CountOverrides(t *testing.T) {
 		"with range overriden by range config": {
 			svcCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{Value: &mockRange},
+					Range: Range{Value: &mockRange},
 				},
 			},
 			envCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{
+					Range: Range{
 						RangeConfig: RangeConfig{
 							Min: aws.Int(2),
 							Max: aws.Int(8),
@@ -790,7 +792,7 @@ func TestBackendSvc_ApplyEnv_CountOverrides(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{
+								Range: Range{
 									RangeConfig: RangeConfig{
 										Min: aws.Int(2),
 										Max: aws.Int(8),
