@@ -123,9 +123,9 @@ func TestScheduledJob_ApplyEnv(t *testing.T) {
 							Value: aws.Int(1),
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement: stringP(PublicSubnetPlacement),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement: &PublicSubnetPlacement,
 						},
 					},
 				},
@@ -169,9 +169,9 @@ func TestScheduledJob_ApplyEnv(t *testing.T) {
 							"LOG_LEVEL": "prod",
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement: stringP(PublicSubnetPlacement),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement: &PublicSubnetPlacement,
 						},
 					},
 				},
@@ -380,7 +380,7 @@ func TestScheduledJob_Publish(t *testing.T) {
 		"returns the list of topics if manifest publishes notifications": {
 			mft: &ScheduledJob{
 				ScheduledJobConfig: ScheduledJobConfig{
-					Publish: &PublishConfig{
+					PublishConfig: PublishConfig{
 						Topics: []Topic{
 							{
 								Name: stringP("hello"),
