@@ -28,7 +28,7 @@ func TestNewLoadBalancedWebService(t *testing.T) {
 					Dockerfile: "./Dockerfile",
 				},
 				Path: "/",
-				HealthCheck: &ContainerHealthCheck{
+				HealthCheck: ContainerHealthCheck{
 					Command: []string{"CMD", "curl -f http://localhost:8080 || exit 1"},
 				},
 				Port: 80,
@@ -51,7 +51,7 @@ func TestNewLoadBalancedWebService(t *testing.T) {
 							},
 							Port: aws.Uint16(80),
 						},
-						HealthCheck: &ContainerHealthCheck{
+						HealthCheck: ContainerHealthCheck{
 							Command: []string{"CMD", "curl -f http://localhost:8080 || exit 1"},
 						},
 					},
@@ -66,14 +66,17 @@ func TestNewLoadBalancedWebService(t *testing.T) {
 						Memory: aws.Int(512),
 						Count: Count{
 							Value: aws.Int(1),
+							AdvancedCount: AdvancedCount{
+								workloadType: LoadBalancedWebServiceType,
+							},
 						},
 						ExecuteCommand: ExecuteCommand{
 							Enable: aws.Bool(false),
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement: stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement: &PublicSubnetPlacement,
 						},
 					},
 				},
@@ -188,7 +191,12 @@ func TestLoadBalancedWebService_MarshalBinary(t *testing.T) {
 }
 
 func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
-	mockRange := IntRangeBand("1-10")
+	var (
+		mockIPNet1 = IPNet("10.1.0.0/24")
+		mockIPNet2 = IPNet("10.1.1.0/24")
+		mockRange  = IntRangeBand("1-10")
+		mockPerc   = Percentage(80)
+	)
 	testCases := map[string]struct {
 		in         *LoadBalancedWebService
 		envToApply string
@@ -226,14 +234,14 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						Count: Count{
 							Value: aws.Int(1),
 						},
-						Storage: &Storage{
+						Storage: Storage{
 							Volumes: map[string]*Volume{
 								"myEFSVolume": {
 									MountPointOpts: MountPointOpts{
 										ContainerPath: aws.String("/path/to/files"),
 										ReadOnly:      aws.Bool(false),
 									},
-									EFS: &EFSConfigOrBool{
+									EFS: EFSConfigOrBool{
 										Advanced: EFSVolumeConfiguration{
 											FileSystemID: aws.String("fs-1234"),
 										},
@@ -276,14 +284,14 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						Count: Count{
 							Value: aws.Int(1),
 						},
-						Storage: &Storage{
+						Storage: Storage{
 							Volumes: map[string]*Volume{
 								"myEFSVolume": {
 									MountPointOpts: MountPointOpts{
 										ContainerPath: aws.String("/path/to/files"),
 										ReadOnly:      aws.Bool(false),
 									},
-									EFS: &EFSConfigOrBool{
+									EFS: EFSConfigOrBool{
 										Advanced: EFSVolumeConfiguration{
 											FileSystemID: aws.String("fs-1234"),
 										},
@@ -334,17 +342,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							"GITHUB_TOKEN": "1111",
 							"TWILIO_TOKEN": "1111",
 						},
-						Storage: &Storage{
+						Storage: Storage{
 							Volumes: map[string]*Volume{
 								"myEFSVolume": {
 									MountPointOpts: MountPointOpts{
 										ContainerPath: aws.String("/path/to/files"),
 										ReadOnly:      aws.Bool(false),
 									},
-									EFS: &EFSConfigOrBool{
+									EFS: EFSConfigOrBool{
 										Advanced: EFSVolumeConfiguration{
 											FileSystemID: aws.String("fs-1234"),
-											AuthConfig: &AuthorizationConfig{
+											AuthConfig: AuthorizationConfig{
 												IAM:           aws.Bool(true),
 												AccessPointID: aws.String("ap-1234"),
 											},
@@ -361,12 +369,12 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							CredsParam: aws.String("some arn"),
 						},
 					},
-					Logging: &Logging{
+					Logging: Logging{
 						ConfigFile: aws.String("mockConfigFile"),
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement:      stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement:      &PublicSubnetPlacement,
 							SecurityGroups: []string{"sg-123"},
 						},
 					},
@@ -396,13 +404,13 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							Variables: map[string]string{
 								"DDB_TABLE_NAME": "awards-prod",
 							},
-							Storage: &Storage{
+							Storage: Storage{
 								Volumes: map[string]*Volume{
 									"myEFSVolume": {
-										EFS: &EFSConfigOrBool{
+										EFS: EFSConfigOrBool{
 											Advanced: EFSVolumeConfiguration{
 												FileSystemID: aws.String("fs-5678"),
-												AuthConfig: &AuthorizationConfig{
+												AuthConfig: AuthorizationConfig{
 													AccessPointID: aws.String("ap-5678"),
 												},
 											},
@@ -425,13 +433,13 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 								},
 							},
 						},
-						Logging: &Logging{
+						Logging: Logging{
 							SecretOptions: map[string]string{
 								"FOO": "BAR",
 							},
 						},
-						Network: &NetworkConfig{
-							VPC: &vpcConfig{
+						Network: NetworkConfig{
+							VPC: vpcConfig{
 								SecurityGroups: []string{"sg-456", "sg-789"},
 							},
 						},
@@ -479,17 +487,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							"GITHUB_TOKEN": "1111",
 							"TWILIO_TOKEN": "1111",
 						},
-						Storage: &Storage{
+						Storage: Storage{
 							Volumes: map[string]*Volume{
 								"myEFSVolume": {
 									MountPointOpts: MountPointOpts{
 										ContainerPath: aws.String("/path/to/files"),
 										ReadOnly:      aws.Bool(false),
 									},
-									EFS: &EFSConfigOrBool{
+									EFS: EFSConfigOrBool{
 										Advanced: EFSVolumeConfiguration{
 											FileSystemID: aws.String("fs-5678"),
-											AuthConfig: &AuthorizationConfig{
+											AuthConfig: AuthorizationConfig{
 												IAM:           aws.Bool(true),
 												AccessPointID: aws.String("ap-5678"),
 											},
@@ -515,15 +523,15 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							},
 						},
 					},
-					Logging: &Logging{
+					Logging: Logging{
 						ConfigFile: aws.String("mockConfigFile"),
 						SecretOptions: map[string]string{
 							"FOO": "BAR",
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement:      stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement:      &PublicSubnetPlacement,
 							SecurityGroups: []string{"sg-456", "sg-789"},
 						},
 					},
@@ -536,16 +544,16 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
-								CPU:   aws.Int(80),
+								Range: Range{Value: &mockRange},
+								CPU:   &mockPerc,
 							},
 						},
 					},
 					ImageOverride: ImageOverride{
-						Command: &CommandOverride{
+						Command: CommandOverride{
 							StringSlice: []string{"command", "default"},
 						},
-						EntryPoint: &EntryPointOverride{
+						EntryPoint: EntryPointOverride{
 							StringSlice: []string{"entrypoint", "default"},
 						},
 					},
@@ -562,16 +570,16 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						Count: Count{
 							Value: nil,
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
-								CPU:   aws.Int(80),
+								Range: Range{Value: &mockRange},
+								CPU:   &mockPerc,
 							},
 						},
 					},
 					ImageOverride: ImageOverride{
-						Command: &CommandOverride{
+						Command: CommandOverride{
 							StringSlice: []string{"command", "default"},
 						},
-						EntryPoint: &EntryPointOverride{
+						EntryPoint: EntryPointOverride{
 							StringSlice: []string{"entrypoint", "default"},
 						},
 					},
@@ -587,14 +595,14 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
-								CPU:   aws.Int(80),
+								Range: Range{Value: &mockRange},
+								CPU:   &mockPerc,
 							},
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement:      stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement:      &PublicSubnetPlacement,
 							SecurityGroups: []string{"sg-456", "sg-789"},
 						},
 					},
@@ -611,14 +619,14 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						Count: Count{
 							Value: nil,
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
-								CPU:   aws.Int(80),
+								Range: Range{Value: &mockRange},
+								CPU:   &mockPerc,
 							},
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement:      stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement:      &PublicSubnetPlacement,
 							SecurityGroups: []string{"sg-456", "sg-789"},
 						},
 					},
@@ -695,7 +703,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
+								Range: Range{Value: &mockRange},
 							},
 						},
 					},
@@ -732,7 +740,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
+								Range: Range{Value: &mockRange},
 							},
 						},
 					},
@@ -742,7 +750,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						TaskConfig: TaskConfig{
 							Count: Count{
 								AdvancedCount: AdvancedCount{
-									Range: &Range{
+									Range: Range{
 										RangeConfig: RangeConfig{
 											Min: aws.Int(2),
 											Max: aws.Int(8),
@@ -761,7 +769,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{
+								Range: Range{
 									RangeConfig: RangeConfig{
 										Min: aws.Int(2),
 										Max: aws.Int(8),
@@ -1006,7 +1014,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageOverride: ImageOverride{
-						Command: &CommandOverride{
+						Command: CommandOverride{
 							StringSlice: []string{"command", "default"},
 						},
 					},
@@ -1014,7 +1022,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 				Environments: map[string]*LoadBalancedWebServiceConfig{
 					"prod-iad": {
 						ImageOverride: ImageOverride{
-							Command: &CommandOverride{
+							Command: CommandOverride{
 								StringSlice: []string{"command", "prod"},
 							},
 						},
@@ -1030,7 +1038,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageOverride: ImageOverride{
-						Command: &CommandOverride{
+						Command: CommandOverride{
 							StringSlice: []string{"command", "prod"},
 						},
 					},
@@ -1048,13 +1056,13 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						HealthCheck: HealthCheckArgsOrString{
 							HealthCheckPath: aws.String("path"),
 						},
-						AllowedSourceIps: &[]string{"ip1", "ip2"},
+						AllowedSourceIps: []IPNet{mockIPNet1},
 					},
 				},
 				Environments: map[string]*LoadBalancedWebServiceConfig{
 					"prod-iad": {
 						RoutingRule: RoutingRule{
-							AllowedSourceIps: &[]string{"ip1", "ip3"},
+							AllowedSourceIps: []IPNet{mockIPNet2},
 						},
 					},
 				},
@@ -1071,7 +1079,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						HealthCheck: HealthCheckArgsOrString{
 							HealthCheckPath: aws.String("path"),
 						},
-						AllowedSourceIps: &[]string{"ip1", "ip3"},
+						AllowedSourceIps: []IPNet{mockIPNet2},
 					},
 				},
 			},
@@ -1087,7 +1095,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						HealthCheck: HealthCheckArgsOrString{
 							HealthCheckPath: aws.String("path"),
 						},
-						AllowedSourceIps: &[]string{"ip1", "ip2"},
+						AllowedSourceIps: []IPNet{mockIPNet1, mockIPNet2},
 					},
 				},
 				Environments: map[string]*LoadBalancedWebServiceConfig{
@@ -1112,7 +1120,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						HealthCheck: HealthCheckArgsOrString{
 							HealthCheckPath: aws.String("another-path"),
 						},
-						AllowedSourceIps: &[]string{"ip1", "ip2"},
+						AllowedSourceIps: []IPNet{mockIPNet1, mockIPNet2},
 					},
 				},
 			},
@@ -1128,7 +1136,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						HealthCheck: HealthCheckArgsOrString{
 							HealthCheckPath: aws.String("path"),
 						},
-						AllowedSourceIps: &[]string{"ip1", "ip2"},
+						AllowedSourceIps: []IPNet{mockIPNet1, mockIPNet2},
 					},
 				},
 				Environments: map[string]*LoadBalancedWebServiceConfig{
@@ -1137,7 +1145,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							HealthCheck: HealthCheckArgsOrString{
 								HealthCheckPath: aws.String("another-path"),
 							},
-							AllowedSourceIps: &[]string{},
+							AllowedSourceIps: []IPNet{},
 						},
 					},
 				},
@@ -1154,7 +1162,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						HealthCheck: HealthCheckArgsOrString{
 							HealthCheckPath: aws.String("another-path"),
 						},
-						AllowedSourceIps: &[]string{},
+						AllowedSourceIps: []IPNet{},
 					},
 				},
 			},
@@ -1204,7 +1212,7 @@ func TestLoadBalancedWebService_Publish(t *testing.T) {
 		"returns the list of topics if manifest publishes notifications": {
 			mft: &LoadBalancedWebService{
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
-					Publish: &PublishConfig{
+					PublishConfig: PublishConfig{
 						Topics: []Topic{
 							{
 								Name: stringP("hello"),
@@ -1248,7 +1256,7 @@ func Test_Temp(t *testing.T) {
 			},
 			Port: aws.Uint16(5000),
 		},
-		HealthCheck: newDefaultContainerHealthCheck(),
+		HealthCheck: *NewDefaultContainerHealthCheck(),
 	}
 	t.Run("temporary", func(t *testing.T) {
 		// WHEN
@@ -1292,7 +1300,7 @@ func Test_Temp(t *testing.T) {
 							},
 							Port: aws.Uint16(5000),
 						},
-						HealthCheck: newDefaultContainerHealthCheck(),
+						HealthCheck: *NewDefaultContainerHealthCheck(),
 					},
 				},
 			},
@@ -1360,3 +1368,30 @@ func TestLoadBalancedWebService_BuildRequired(t *testing.T) {
 		})
 	}
 }
+
+func TestAlias_IsEmpty(t *testing.T) {
+	testCases := map[string]struct {
+		in     Alias
+		wanted bool
+	}{
+		"empty alias": {
+			in:     Alias{},
+			wanted: true,
+		},
+		"non empty alias": {
+			in: Alias{
+				String: aws.String("alias test"),
+			},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// WHEN
+			got := tc.in.IsEmpty()
+
+			// THEN
+			require.Equal(t, tc.wanted, got)
+		})
+	}
+}
