@@ -4,6 +4,7 @@
 package manifest
 
 import (
+	"errors"
 	"fmt"
 	"testing"
 	"time"
@@ -14,6 +15,7 @@ import (
 )
 
 func TestUnmarshalSvc(t *testing.T) {
+	mockPerc := Percentage(70)
 	testCases := map[string]struct {
 		inContent string
 
@@ -42,6 +44,9 @@ http:
   alias:
     - foobar.com
     - v1.foobar.com
+  allowed_source_ips:
+    - 10.1.0.0/24
+    - 10.1.1.0/24
 variables:
   LOG_LEVEL: "WARN"
 secrets:
@@ -91,7 +96,7 @@ environments:
 							}, Port: aws.Uint16(80)},
 						},
 						RoutingRule: RoutingRule{
-							Alias: &Alias{
+							Alias: Alias{
 								StringSlice: []string{
 									"foobar.com",
 									"v1.foobar.com",
@@ -102,13 +107,16 @@ environments:
 							HealthCheck: HealthCheckArgsOrString{
 								HealthCheckPath: aws.String("/"),
 							},
+							AllowedSourceIps: []IPNet{IPNet("10.1.0.0/24"), IPNet("10.1.1.0/24")},
 						},
 						TaskConfig: TaskConfig{
-							CPU:      aws.Int(512),
-							Memory:   aws.Int(1024),
-							Platform: nil,
+							CPU:    aws.Int(512),
+							Memory: aws.Int(1024),
 							Count: Count{
 								Value: aws.Int(1),
+								AdvancedCount: AdvancedCount{
+									workloadType: LoadBalancedWebServiceType,
+								},
 							},
 							ExecuteCommand: ExecuteCommand{
 								Enable: aws.Bool(true),
@@ -127,7 +135,7 @@ environments:
 								CredsParam: aws.String("some arn"),
 							},
 						},
-						Logging: &Logging{
+						Logging: Logging{
 							Destination: map[string]string{
 								"exclude-pattern": "^.*[aeiou]$",
 								"include-pattern": "^[a-z][aeiou].*$",
@@ -139,9 +147,9 @@ environments:
 								"LOG_TOKEN": "LOG_TOKEN",
 							},
 						},
-						Network: &NetworkConfig{
-							VPC: &vpcConfig{
-								Placement: stringP("public"),
+						Network: NetworkConfig{
+							VPC: vpcConfig{
+								Placement: &PublicSubnetPlacement,
 							},
 						},
 						TaskDefOverrides: []OverrideRule{
@@ -179,7 +187,7 @@ environments:
 							TaskConfig: TaskConfig{
 								Count: Count{
 									AdvancedCount: AdvancedCount{
-										Range: &Range{
+										Range: Range{
 											RangeConfig: RangeConfig{
 												Min:      aws.Int(2),
 												Max:      aws.Int(8),
@@ -194,10 +202,10 @@ environments:
 							TaskConfig: TaskConfig{
 								Count: Count{
 									AdvancedCount: AdvancedCount{
-										Range: &Range{
+										Range: Range{
 											Value: &mockRange,
 										},
-										CPU: aws.Int(70),
+										CPU: &mockPerc,
 									},
 								},
 							},
@@ -229,8 +237,8 @@ secrets:
 						Type: aws.String(BackendServiceType),
 					},
 					BackendServiceConfig: BackendServiceConfig{
-						ImageConfig: ImageWithPortAndHealthcheck{
-							ImageWithPort: ImageWithPort{
+						ImageConfig: ImageWithHealthcheckAndOptionalPort{
+							ImageWithOptionalPort: ImageWithOptionalPort{
 								Image: Image{
 									Build: BuildArgsOrString{
 										BuildString: aws.String("./subscribers/Dockerfile"),
@@ -238,16 +246,18 @@ secrets:
 								},
 								Port: aws.Uint16(8080),
 							},
-							HealthCheck: &ContainerHealthCheck{
+							HealthCheck: ContainerHealthCheck{
 								Command: []string{"CMD-SHELL", "curl http://localhost:5000/ || exit 1"},
 							},
 						},
 						TaskConfig: TaskConfig{
-							CPU:      aws.Int(1024),
-							Memory:   aws.Int(1024),
-							Platform: nil,
+							CPU:    aws.Int(1024),
+							Memory: aws.Int(1024),
 							Count: Count{
 								Value: aws.Int(1),
+								AdvancedCount: AdvancedCount{
+									workloadType: BackendServiceType,
+								},
 							},
 							ExecuteCommand: ExecuteCommand{
 								Enable: aws.Bool(false),
@@ -256,9 +266,9 @@ secrets:
 								"API_TOKEN": "SUBS_API_TOKEN",
 							},
 						},
-						Network: &NetworkConfig{
-							VPC: &vpcConfig{
-								Placement: stringP("public"),
+						Network: NetworkConfig{
+							VPC: vpcConfig{
+								Placement: &PublicSubnetPlacement,
 							},
 						},
 					},
@@ -307,38 +317,42 @@ subscribe:
 							},
 						},
 						TaskConfig: TaskConfig{
-							CPU:      aws.Int(1024),
-							Memory:   aws.Int(1024),
-							Platform: nil,
+							CPU:    aws.Int(1024),
+							Memory: aws.Int(1024),
 							Count: Count{
 								Value: aws.Int(1),
+								AdvancedCount: AdvancedCount{
+									workloadType: WorkerServiceType,
+								},
 							},
 							ExecuteCommand: ExecuteCommand{
 								Enable: aws.Bool(true),
 							},
 						},
-						Network: &NetworkConfig{
-							VPC: &vpcConfig{
-								Placement: stringP("public"),
+						Network: NetworkConfig{
+							VPC: vpcConfig{
+								Placement: &PublicSubnetPlacement,
 							},
 						},
-						Subscribe: &SubscribeConfig{
+						Subscribe: SubscribeConfig{
 							Topics: []TopicSubscription{
 								{
-									Name:    "publisher1",
-									Service: "testpubsvc",
+									Name:    aws.String("publisher1"),
+									Service: aws.String("testpubsvc"),
 								},
 								{
-									Name:    "publisher2",
-									Service: "testpubjob",
-									Queue: &SQSQueue{
-										Timeout: &duration15Seconds,
+									Name:    aws.String("publisher2"),
+									Service: aws.String("testpubjob"),
+									Queue: SQSQueueOrBool{
+										Advanced: SQSQueue{
+											Timeout: &duration15Seconds,
+										},
 									},
 								},
 							},
-							Queue: &SQSQueue{
+							Queue: SQSQueue{
 								Delay: &duration15Seconds,
-								DeadLetter: &DeadLetterQueue{
+								DeadLetter: DeadLetterQueue{
 									Tries: aws.Uint16(5),
 								},
 							},
@@ -372,8 +386,12 @@ type: 'OH NO'
 }
 
 func TestCount_UnmarshalYAML(t *testing.T) {
-	mockResponseTime := 500 * time.Millisecond
-	mockRange := IntRangeBand("1-10")
+	var (
+		mockResponseTime = 500 * time.Millisecond
+		mockRange        = IntRangeBand("1-10")
+		mockCPU          = Percentage(70)
+		mockMem          = Percentage(80)
+	)
 	testCases := map[string]struct {
 		inContent []byte
 
@@ -397,9 +415,9 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 `),
 			wantedStruct: Count{
 				AdvancedCount: AdvancedCount{
-					Range:        &Range{Value: &mockRange},
-					CPU:          aws.Int(70),
-					Memory:       aws.Int(80),
+					Range:        Range{Value: &mockRange},
+					CPU:          &mockCPU,
+					Memory:       &mockMem,
 					Requests:     aws.Int(1000),
 					ResponseTime: &mockResponseTime,
 				},
@@ -423,7 +441,7 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 `),
 			wantedStruct: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{
+					Range: Range{
 						RangeConfig: RangeConfig{
 							Min: aws.Int(5),
 							Max: aws.Int(15),
@@ -432,58 +450,37 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 				},
 			},
 		},
-		"With all RangeConfig fields specified": {
-			inContent: []byte(`count:
-  range:
-    min: 2
-    max: 8
-    spot_from: 3
-`),
-			wantedStruct: Count{
-				AdvancedCount: AdvancedCount{
-					Range: &Range{
-						RangeConfig: RangeConfig{
-							Min:      aws.Int(2),
-							Max:      aws.Int(8),
-							SpotFrom: aws.Int(3),
-						},
-					},
-				},
-			},
-		},
 		"With all RangeConfig fields specified and autoscaling field": {
 			inContent: []byte(`count:
   range:
     min: 2
     max: 8
     spot_from: 3
-  cpu_percentage: 50
+  cpu_percentage: 70
 `),
 			wantedStruct: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{
+					Range: Range{
 						RangeConfig: RangeConfig{
 							Min:      aws.Int(2),
 							Max:      aws.Int(8),
 							SpotFrom: aws.Int(3),
 						},
 					},
-					CPU: aws.Int(50),
+					CPU: &mockCPU,
 				},
 			},
 		},
-		"Error if spot specified as int with range": {
-			inContent: []byte(`count:
-  range: 1-10
-  spot: 3
-`),
-			wantedError: errInvalidAdvancedCount,
-		},
-		"Error if autoscaling specified without range": {
+
+		"Error if mutually exclusive fields are specified": {
 			inContent: []byte(`count:
+  spot: 1
   cpu_percentage: 30
 `),
-			wantedError: errInvalidAutoscaling,
+			wantedError: &errFieldMutualExclusive{
+				firstField:  "spot",
+				secondField: "range/cpu_percentage/memory_percentage/requests/response_time/queue_delay",
+			},
 		},
 		"Error if unmarshalable": {
 			inContent: []byte(`count: badNumber
@@ -565,20 +562,16 @@ func TestRange_Parse(t *testing.T) {
 
 		wantedMin int
 		wantedMax int
-		wantedErr error
 	}{
-		"error when both range and RangeConfig specified": {
+		"success with range value": {
 			input: Range{
 				Value: &mockRange,
-				RangeConfig: RangeConfig{
-					Min: aws.Int(1),
-					Max: aws.Int(3),
-				},
 			},
 
-			wantedErr: errInvalidRangeOpts,
+			wantedMin: 1,
+			wantedMax: 10,
 		},
-		"success": {
+		"success with range config": {
 			input: Range{
 				RangeConfig: RangeConfig{
 					Min: aws.Int(2),
@@ -594,13 +587,9 @@ func TestRange_Parse(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			gotMin, gotMax, err := tc.input.Parse()
 
-			if tc.wantedErr != nil {
-				require.EqualError(t, err, tc.wantedErr.Error())
-			} else {
-				require.NoError(t, err)
-				require.Equal(t, tc.wantedMin, gotMin)
-				require.Equal(t, tc.wantedMax, gotMax)
-			}
+			require.NoError(t, err)
+			require.Equal(t, tc.wantedMin, gotMin)
+			require.Equal(t, tc.wantedMax, gotMax)
 		})
 	}
 }
@@ -693,7 +682,7 @@ func TestCount_Desired(t *testing.T) {
 		"with autoscaling range on dedicated capacity": {
 			input: &Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{
+					Range: Range{
 						Value: &mockRange,
 					},
 				},
@@ -703,7 +692,7 @@ func TestCount_Desired(t *testing.T) {
 		"with autoscaling range with spot capacity": {
 			input: &Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{
+					Range: Range{
 						RangeConfig: RangeConfig{
 							Min: aws.Int(5),
 							Max: aws.Int(10),
@@ -730,144 +719,6 @@ func TestCount_Desired(t *testing.T) {
 	}
 }
 
-func TestAdvancedCount_IsValid(t *testing.T) {
-	mockRange := IntRangeBand("1-10")
-	testCases := map[string]struct {
-		input *AdvancedCount
-
-		expectedErr error
-	}{
-		"with spot count": {
-			input: &AdvancedCount{
-				Spot: aws.Int(42),
-			},
-
-			expectedErr: nil,
-		},
-		"with range value": {
-			input: &AdvancedCount{
-				Range: &Range{
-					Value: &mockRange,
-				},
-			},
-
-			expectedErr: nil,
-		},
-		"with range config": {
-			input: &AdvancedCount{
-				Range: &Range{
-					RangeConfig: RangeConfig{
-						Min:      aws.Int(1),
-						Max:      aws.Int(10),
-						SpotFrom: aws.Int(2),
-					},
-				},
-			},
-
-			expectedErr: nil,
-		},
-		"with range and autoscaling config": {
-			input: &AdvancedCount{
-				Range: &Range{
-					Value: &mockRange,
-				},
-				CPU:      aws.Int(512),
-				Memory:   aws.Int(1024),
-				Requests: aws.Int(1000),
-			},
-
-			expectedErr: nil,
-		},
-		"with range config and autoscaling config": {
-			input: &AdvancedCount{
-				Range: &Range{
-					RangeConfig: RangeConfig{
-						Min: aws.Int(1),
-						Max: aws.Int(10),
-					},
-				},
-				CPU:      aws.Int(512),
-				Memory:   aws.Int(1024),
-				Requests: aws.Int(1000),
-			},
-
-			expectedErr: nil,
-		},
-		"with range config with spot and autoscaling config": {
-			input: &AdvancedCount{
-				Range: &Range{
-					RangeConfig: RangeConfig{
-						Min:      aws.Int(1),
-						Max:      aws.Int(10),
-						SpotFrom: aws.Int(3),
-					},
-				},
-				CPU:      aws.Int(512),
-				Memory:   aws.Int(1024),
-				Requests: aws.Int(1000),
-			},
-
-			expectedErr: nil,
-		},
-		"invalid with spot count and autoscaling config": {
-			input: &AdvancedCount{
-				Spot:     aws.Int(42),
-				CPU:      aws.Int(512),
-				Memory:   aws.Int(1024),
-				Requests: aws.Int(1000),
-			},
-
-			expectedErr: errInvalidAdvancedCount,
-		},
-		"invalid with spot count and range": {
-			input: &AdvancedCount{
-				Spot: aws.Int(42),
-				Range: &Range{
-					Value: &mockRange,
-				},
-			},
-
-			expectedErr: errInvalidAdvancedCount,
-		},
-		"invalid with spot count and range config": {
-			input: &AdvancedCount{
-				Spot: aws.Int(42),
-				Range: &Range{
-					RangeConfig: RangeConfig{
-						Min:      aws.Int(1),
-						Max:      aws.Int(10),
-						SpotFrom: aws.Int(3),
-					},
-				},
-			},
-
-			expectedErr: errInvalidAdvancedCount,
-		},
-		"invalid with autoscaling fields and no range": {
-			input: &AdvancedCount{
-				CPU:      aws.Int(512),
-				Memory:   aws.Int(1024),
-				Requests: aws.Int(1000),
-			},
-
-			expectedErr: errInvalidAutoscaling,
-		},
-	}
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			// WHEN
-			err := tc.input.IsValid()
-
-			// THEN
-			if tc.expectedErr != nil {
-				require.EqualError(t, err, tc.expectedErr.Error())
-			} else {
-				require.NoError(t, err)
-			}
-		})
-	}
-}
-
 func TestHealthCheckArgsOrString_IsEmpty(t *testing.T) {
 	testCases := map[string]struct {
 		hc     HealthCheckArgsOrString
@@ -898,3 +749,61 @@ func TestHealthCheckArgsOrString_IsEmpty(t *testing.T) {
 		})
 	}
 }
+
+func TestQueueScaling_IsEmpty(t *testing.T) {
+	testCases := map[string]struct {
+		in     QueueScaling
+		wanted bool
+	}{
+		"should return false if msg_processing_time is not nil": {
+			in: QueueScaling{
+				AvgProcessingTime: durationp(5 * time.Second),
+			},
+		},
+		"should return false if acceptable_latency is not nil": {
+			in: QueueScaling{
+				AcceptableLatency: durationp(1 * time.Minute),
+			},
+		},
+		"should return true if there are no fields set": {
+			wanted: true,
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			require.Equal(t, tc.wanted, tc.in.IsEmpty())
+		})
+	}
+}
+
+func TestQueueScaling_AcceptableBacklogPerTask(t *testing.T) {
+	testCases := map[string]struct {
+		in            QueueScaling
+		wantedBacklog int
+		wantedErr     error
+	}{
+		"should return an error if queue scaling is empty": {
+			in:        QueueScaling{},
+			wantedErr: errors.New(`"queue_delay" must be specified in order to calculate the acceptable backlog`),
+		},
+		"should round up to an integer if backlog number has a decimal": {
+			in: QueueScaling{
+				AcceptableLatency: durationp(10 * time.Second),
+				AvgProcessingTime: durationp(300 * time.Millisecond),
+			},
+			wantedBacklog: 34,
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			actual, err := tc.in.AcceptableBacklogPerTask()
+			if tc.wantedErr != nil {
+				require.NotNil(t, err)
+			} else {
+				require.Equal(t, tc.wantedBacklog, actual)
+			}
+		})
+	}
+}
