@@ -4,17 +4,23 @@
 package manifest
 
 import (
+	"errors"
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/imdario/mergo"
+	"gopkg.in/yaml.v3"
 )
 
 const (
 	workerSvcManifestPath = "workloads/services/worker/manifest.yml"
 )
 
+var (
+	errUnmarshalQueueOpts = errors.New(`cannot unmarshal "queue" field into bool or map`)
+)
+
 // WorkerService holds the configuration to create a worker service.
 type WorkerService struct {
 	Workload            `yaml:",inline"`
@@ -30,32 +36,76 @@ type WorkerServiceConfig struct {
 	ImageConfig      ImageWithHealthcheck `yaml:"image,flow"`
 	ImageOverride    `yaml:",inline"`
 	TaskConfig       `yaml:",inline"`
-	*Logging         `yaml:"logging,flow"`
-	Sidecars         map[string]*SidecarConfig `yaml:"sidecars"`
-	Subscribe        *SubscribeConfig          `yaml:"subscribe"`
-	Network          *NetworkConfig            `yaml:"network"`
+	Logging          `yaml:"logging,flow"`
+	Sidecars         map[string]*SidecarConfig `yaml:"sidecars"` // NOTE: keep the pointers because `mergo` doesn't automatically deep merge map's value unless it's a pointer type.
+	Subscribe        SubscribeConfig           `yaml:"subscribe"`
+	Network          NetworkConfig             `yaml:"network"`
 	TaskDefOverrides []OverrideRule            `yaml:"taskdef_overrides"`
 }
 
 // SubscribeConfig represents the configurable options for setting up subscriptions.
 type SubscribeConfig struct {
 	Topics []TopicSubscription `yaml:"topics"`
-	Queue  *SQSQueue           `yaml:"queue"`
+	Queue  SQSQueue            `yaml:"queue"`
+}
+
+// IsEmpty returns empty if the struct has all zero members.
+func (s *SubscribeConfig) IsEmpty() bool {
+	return s.Topics == nil && s.Queue.IsEmpty()
 }
 
 // TopicSubscription represents the configurable options for setting up a SNS Topic Subscription.
 type TopicSubscription struct {
-	Name    string    `yaml:"name"`
-	Service string    `yaml:"service"`
-	Queue   *SQSQueue `yaml:"queue"`
+	Name    *string        `yaml:"name"`
+	Service *string        `yaml:"service"`
+	Queue   SQSQueueOrBool `yaml:"queue"`
+}
+
+// SQSQueueOrBool contains custom unmarshaling logic for the `queue` field in the manifest.
+type SQSQueueOrBool struct {
+	Advanced SQSQueue
+	Enabled  *bool
+}
+
+// IsEmpty returns empty if the struct has all zero members.
+func (q *SQSQueueOrBool) IsEmpty() bool {
+	return q.Advanced.IsEmpty() && q.Enabled == nil
+}
+
+// UnmarshalYAML implements the yaml(v3) interface. It allows SQSQueue to be specified as a
+// string or a struct alternately.
+func (q *SQSQueueOrBool) UnmarshalYAML(value *yaml.Node) error {
+	if err := value.Decode(&q.Advanced); err != nil {
+		switch err.(type) {
+		case *yaml.TypeError:
+			break
+		default:
+			return err
+		}
+	}
+	if !q.Advanced.IsEmpty() {
+		// Unmarshaled successfully to q.Advanced, unset q.Enabled, and return.
+		q.Enabled = nil
+		return nil
+	}
+	if err := value.Decode(&q.Enabled); err != nil {
+		return errUnmarshalQueueOpts
+	}
+	return nil
 }
 
 // SQSQueue represents the configurable options for setting up a SQS Queue.
 type SQSQueue struct {
-	Retention  *time.Duration   `yaml:"retention"`
-	Delay      *time.Duration   `yaml:"delay"`
-	Timeout    *time.Duration   `yaml:"timeout"`
-	DeadLetter *DeadLetterQueue `yaml:"dead_letter"`
+	Retention  *time.Duration  `yaml:"retention"`
+	Delay      *time.Duration  `yaml:"delay"`
+	Timeout    *time.Duration  `yaml:"timeout"`
+	DeadLetter DeadLetterQueue `yaml:"dead_letter"`
+}
+
+// IsEmpty returns empty if the struct has all zero members.
+func (q *SQSQueue) IsEmpty() bool {
+	return q.Retention == nil && q.Delay == nil && q.Timeout == nil &&
+		q.DeadLetter.IsEmpty()
 }
 
 // DeadLetterQueue represents the configurable options for setting up a Dead-Letter Queue.
@@ -63,11 +113,18 @@ type DeadLetterQueue struct {
 	Tries *uint16 `yaml:"tries"`
 }
 
+// IsEmpty returns empty if the struct has all zero members.
+func (q *DeadLetterQueue) IsEmpty() bool {
+	return q.Tries == nil
+}
+
 // WorkerServiceProps represents the configuration needed to create a worker service.
 type WorkerServiceProps struct {
 	WorkloadProps
-	HealthCheck *ContainerHealthCheck // Optional healthcheck configuration.
-	Topics      []TopicSubscription   // Optional topics for subscriptions
+
+	HealthCheck ContainerHealthCheck // Optional healthcheck configuration.
+	Platform    PlatformArgsOrString // Optional platform configuration.
+	Topics      []TopicSubscription  // Optional topics for subscriptions
 }
 
 // NewWorkerService applies the props to a default Worker service configuration with
@@ -77,9 +134,10 @@ func NewWorkerService(props WorkerServiceProps) *WorkerService {
 	// Apply overrides.
 	svc.Name = stringP(props.Name)
 	svc.WorkerServiceConfig.ImageConfig.Image.Location = stringP(props.Image)
-	svc.WorkerServiceConfig.ImageConfig.Build.BuildArgs.Dockerfile = stringP(props.Dockerfile)
+	svc.WorkerServiceConfig.ImageConfig.Image.Build.BuildArgs.Dockerfile = stringP(props.Dockerfile)
 	svc.WorkerServiceConfig.ImageConfig.HealthCheck = props.HealthCheck
 	svc.WorkerServiceConfig.Subscribe.Topics = props.Topics
+	svc.WorkerServiceConfig.Platform = props.Platform
 	svc.parser = template.New()
 	return svc
 }
@@ -104,16 +162,13 @@ func (s *WorkerService) BuildRequired() (bool, error) {
 
 // BuildArgs returns a docker.BuildArguments object for the service given a workspace root directory
 func (s *WorkerService) BuildArgs(wsRoot string) *DockerBuildArgs {
-	return s.ImageConfig.BuildConfig(wsRoot)
+	return s.ImageConfig.Image.BuildConfig(wsRoot)
 }
 
 // Subscriptions returns a list of TopicSubscriotion objects which represent the SNS topics the service
 // receives messages from.
 func (s *WorkerService) Subscriptions() []TopicSubscription {
-	if s.Subscribe != nil {
-		return s.Subscribe.Topics
-	}
-	return nil
+	return s.Subscribe.Topics
 }
 
 // ApplyEnv returns the service manifest with environment overrides.
@@ -150,20 +205,23 @@ func newDefaultWorkerService() *WorkerService {
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
 			ImageConfig: ImageWithHealthcheck{},
-			Subscribe:   &SubscribeConfig{},
+			Subscribe:   SubscribeConfig{},
 			TaskConfig: TaskConfig{
 				CPU:    aws.Int(256),
 				Memory: aws.Int(512),
 				Count: Count{
 					Value: aws.Int(1),
+					AdvancedCount: AdvancedCount{ // Leave advanced count empty while passing down the type of the workload.
+						workloadType: WorkerServiceType,
+					},
 				},
 				ExecuteCommand: ExecuteCommand{
 					Enable: aws.Bool(false),
 				},
 			},
-			Network: &NetworkConfig{
-				VPC: &vpcConfig{
-					Placement: aws.String(PublicSubnetPlacement),
+			Network: NetworkConfig{
+				VPC: vpcConfig{
+					Placement: &PublicSubnetPlacement,
 				},
 			},
 		},
