@@ -14,6 +14,22 @@ import (
 	"gopkg.in/yaml.v3"
 )
 
+func newMockSQSQueueOrBool() SQSQueueOrBool {
+	return SQSQueueOrBool{
+		Advanced: newMockSQSQueue(),
+	}
+}
+
+func newMockSQSQueue() SQSQueue {
+	duration111Seconds := 111 * time.Second
+	return SQSQueue{
+		Retention:  &duration111Seconds,
+		Delay:      &duration111Seconds,
+		Timeout:    &duration111Seconds,
+		DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+	}
+}
+
 func TestNewWorkerSvc(t *testing.T) {
 	testCases := map[string]struct {
 		inProps WorkerServiceProps
@@ -42,7 +58,7 @@ func TestNewWorkerSvc(t *testing.T) {
 							},
 						},
 					},
-					Subscribe: &SubscribeConfig{},
+					Subscribe: SubscribeConfig{},
 					TaskConfig: TaskConfig{
 						CPU:    aws.Int(256),
 						Memory: aws.Int(512),
@@ -53,9 +69,9 @@ func TestNewWorkerSvc(t *testing.T) {
 							Enable: aws.Bool(false),
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement: stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement: &PublicSubnetPlacement,
 						},
 					},
 				},
@@ -83,7 +99,7 @@ func TestNewWorkerSvc(t *testing.T) {
 							},
 						},
 					},
-					Subscribe: &SubscribeConfig{},
+					Subscribe: SubscribeConfig{},
 					TaskConfig: TaskConfig{
 						CPU:    aws.Int(256),
 						Memory: aws.Int(512),
@@ -94,9 +110,9 @@ func TestNewWorkerSvc(t *testing.T) {
 							Enable: aws.Bool(false),
 						},
 					},
-					Network: &NetworkConfig{
-						VPC: &vpcConfig{
-							Placement: stringP("public"),
+					Network: NetworkConfig{
+						VPC: vpcConfig{
+							Placement: &PublicSubnetPlacement,
 						},
 					},
 				},
@@ -131,6 +147,13 @@ func TestWorkerSvc_MarshalBinary(t *testing.T) {
 					Name:       "testers",
 					Dockerfile: "./testers/Dockerfile",
 				},
+				Platform: PlatformArgsOrString{
+					PlatformString: nil,
+					PlatformArgs: PlatformArgs{
+						OSFamily: nil,
+						Arch:     nil,
+					},
+				},
 			},
 			wantedTestdata: "worker-svc-nosubscribe.yml",
 		},
@@ -140,14 +163,21 @@ func TestWorkerSvc_MarshalBinary(t *testing.T) {
 					Name:       "testers",
 					Dockerfile: "./testers/Dockerfile",
 				},
+				Platform: PlatformArgsOrString{
+					PlatformString: nil,
+					PlatformArgs: PlatformArgs{
+						OSFamily: nil,
+						Arch:     nil,
+					},
+				},
 				Topics: []TopicSubscription{
 					{
-						Name:    "testTopic",
-						Service: "service4TestTopic",
+						Name:    aws.String("testTopic"),
+						Service: aws.String("service4TestTopic"),
 					},
 					{
-						Name:    "testTopic2",
-						Service: "service4TestTopic2",
+						Name:    aws.String("testTopic2"),
+						Service: aws.String("service4TestTopic2"),
 					},
 				},
 			},
@@ -174,6 +204,7 @@ func TestWorkerSvc_MarshalBinary(t *testing.T) {
 }
 
 func TestWorkerSvc_ApplyEnv(t *testing.T) {
+	mockPerc := Percentage(70)
 	mockWorkerServiceWithNoEnvironments := WorkerService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
@@ -188,7 +219,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						},
 					},
 				},
-				HealthCheck: &ContainerHealthCheck{
+				HealthCheck: ContainerHealthCheck{
 					Command:     []string{"hello", "world"},
 					Interval:    durationp(1 * time.Second),
 					Retries:     aws.Int(100),
@@ -252,17 +283,17 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Image: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
 				},
 			},
-			Logging: &Logging{
+			Logging: Logging{
 				Destination: map[string]string{
 					"Name":            "datadog",
 					"exclude-pattern": "*",
 				},
 			},
-			Subscribe: &SubscribeConfig{
+			Subscribe: SubscribeConfig{
 				Topics: []TopicSubscription{
 					{
-						Name:    "topicName",
-						Service: "bestService",
+						Name:    aws.String("topicName"),
+						Service: aws.String("bestService"),
 					},
 				},
 			},
@@ -279,7 +310,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 				TaskConfig: TaskConfig{
 					Count: Count{
 						AdvancedCount: AdvancedCount{
-							CPU: aws.Int(70),
+							CPU: &mockPerc,
 						},
 					},
 					CPU: aws.Int(512),
@@ -292,17 +323,17 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						CredsParam: aws.String("some arn"),
 					},
 				},
-				Logging: &Logging{
+				Logging: Logging{
 					Destination: map[string]string{
 						"include-pattern": "*",
 						"exclude-pattern": "fe/",
 					},
 				},
-				Subscribe: &SubscribeConfig{
+				Subscribe: SubscribeConfig{
 					Topics: []TopicSubscription{
 						{
-							Name:    "topicName2",
-							Service: "bestService2",
+							Name:    aws.String("topicName2"),
+							Service: aws.String("bestService2"),
 						},
 					},
 				},
@@ -410,31 +441,25 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			},
 		},
 	}
-	duration111Seconds := 111 * time.Second
 	mockWorkerServiceWithSubscribeNilOverride := WorkerService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
+			Subscribe: SubscribeConfig{
 				Topics: []TopicSubscription{
 					{
-						Name:    "name",
-						Service: "svc",
-						Queue: &SQSQueue{
-							Retention:  &duration111Seconds,
-							Delay:      &duration111Seconds,
-							Timeout:    &duration111Seconds,
-							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						},
+						Name:    aws.String("name"),
+						Service: aws.String("svc"),
+						Queue:   newMockSQSQueueOrBool(),
 					},
 				},
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: nil,
+				Subscribe: SubscribeConfig{},
 			},
 		},
 	}
@@ -444,21 +469,16 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: nil,
+			Subscribe: SubscribeConfig{},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{
+				Subscribe: SubscribeConfig{
 					Topics: []TopicSubscription{
 						{
-							Name:    "name",
-							Service: "svc",
-							Queue: &SQSQueue{
-								Retention:  &duration111Seconds,
-								Delay:      &duration111Seconds,
-								Timeout:    &duration111Seconds,
-								DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							},
+							Name:    aws.String("name"),
+							Service: aws.String("svc"),
+							Queue:   newMockSQSQueueOrBool(),
 						},
 					},
 				},
@@ -471,24 +491,19 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
+			Subscribe: SubscribeConfig{
 				Topics: []TopicSubscription{
 					{
-						Name:    "name",
-						Service: "svc",
-						Queue: &SQSQueue{
-							Retention:  &duration111Seconds,
-							Delay:      &duration111Seconds,
-							Timeout:    &duration111Seconds,
-							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						},
+						Name:    aws.String("name"),
+						Service: aws.String("svc"),
+						Queue:   newMockSQSQueueOrBool(),
 					},
 				},
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{},
+				Subscribe: SubscribeConfig{},
 			},
 		},
 	}
@@ -498,23 +513,18 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
+			Subscribe: SubscribeConfig{
 				Topics: nil,
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{
+				Subscribe: SubscribeConfig{
 					Topics: []TopicSubscription{
 						{
-							Name:    "name",
-							Service: "svc",
-							Queue: &SQSQueue{
-								Retention:  &duration111Seconds,
-								Delay:      &duration111Seconds,
-								Timeout:    &duration111Seconds,
-								DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							},
+							Name:    aws.String("name"),
+							Service: aws.String("svc"),
+							Queue:   newMockSQSQueueOrBool(),
 						},
 					},
 				},
@@ -527,24 +537,19 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
+			Subscribe: SubscribeConfig{
 				Topics: []TopicSubscription{
 					{
-						Name:    "name",
-						Service: "svc",
-						Queue: &SQSQueue{
-							Retention:  &duration111Seconds,
-							Delay:      &duration111Seconds,
-							Timeout:    &duration111Seconds,
-							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						},
+						Name:    aws.String("name"),
+						Service: aws.String("svc"),
+						Queue:   newMockSQSQueueOrBool(),
 					},
 				},
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{
+				Subscribe: SubscribeConfig{
 					Topics: nil,
 				},
 			},
@@ -556,23 +561,18 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
+			Subscribe: SubscribeConfig{
 				Topics: []TopicSubscription{},
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{
+				Subscribe: SubscribeConfig{
 					Topics: []TopicSubscription{
 						{
-							Name:    "name",
-							Service: "svc",
-							Queue: &SQSQueue{
-								Retention:  &duration111Seconds,
-								Delay:      &duration111Seconds,
-								Timeout:    &duration111Seconds,
-								DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							},
+							Name:    aws.String("name"),
+							Service: aws.String("svc"),
+							Queue:   newMockSQSQueueOrBool(),
 						},
 					},
 				},
@@ -585,19 +585,14 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
-				Queue: nil,
+			Subscribe: SubscribeConfig{
+				Queue: SQSQueue{},
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{
-					Queue: &SQSQueue{
-						Retention:  &duration111Seconds,
-						Delay:      &duration111Seconds,
-						Timeout:    &duration111Seconds,
-						DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-					},
+				Subscribe: SubscribeConfig{
+					Queue: newMockSQSQueue(),
 				},
 			},
 		},
@@ -608,19 +603,14 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
-				Queue: &SQSQueue{
-					Retention:  &duration111Seconds,
-					Delay:      &duration111Seconds,
-					Timeout:    &duration111Seconds,
-					DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-				},
+			Subscribe: SubscribeConfig{
+				Queue: newMockSQSQueue(),
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{
-					Queue: nil,
+				Subscribe: SubscribeConfig{
+					Queue: SQSQueue{},
 				},
 			},
 		},
@@ -631,19 +621,14 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 			Type: aws.String(WorkerServiceType),
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
-			Subscribe: &SubscribeConfig{
-				Queue: &SQSQueue{},
+			Subscribe: SubscribeConfig{
+				Queue: SQSQueue{},
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
-				Subscribe: &SubscribeConfig{
-					Queue: &SQSQueue{
-						Retention:  &duration111Seconds,
-						Delay:      &duration111Seconds,
-						Timeout:    &duration111Seconds,
-						DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-					},
+				Subscribe: SubscribeConfig{
+					Queue: newMockSQSQueue(),
 				},
 			},
 		},
@@ -700,7 +685,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						Memory: aws.Int(256),
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								CPU: aws.Int(70),
+								CPU: &mockPerc,
 							},
 						},
 						Variables: map[string]string{
@@ -714,18 +699,18 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 							CredsParam: aws.String("some arn"),
 						},
 					},
-					Logging: &Logging{
+					Logging: Logging{
 						Destination: map[string]string{
 							"Name":            "datadog",
 							"include-pattern": "*",
 							"exclude-pattern": "fe/",
 						},
 					},
-					Subscribe: &SubscribeConfig{
+					Subscribe: SubscribeConfig{
 						Topics: []TopicSubscription{
 							{
-								Name:    "topicName2",
-								Service: "bestService2",
+								Name:    aws.String("topicName2"),
+								Service: aws.String("bestService2"),
 							},
 						},
 					},
@@ -820,17 +805,12 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(WorkerServiceType),
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
-					Subscribe: &SubscribeConfig{
+					Subscribe: SubscribeConfig{
 						Topics: []TopicSubscription{
 							{
-								Name:    "name",
-								Service: "svc",
-								Queue: &SQSQueue{
-									Retention:  &duration111Seconds,
-									Delay:      &duration111Seconds,
-									Timeout:    &duration111Seconds,
-									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								},
+								Name:    aws.String("name"),
+								Service: aws.String("svc"),
+								Queue:   newMockSQSQueueOrBool(),
 							},
 						},
 					},
@@ -848,17 +828,12 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(WorkerServiceType),
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
-					Subscribe: &SubscribeConfig{
+					Subscribe: SubscribeConfig{
 						Topics: []TopicSubscription{
 							{
-								Name:    "name",
-								Service: "svc",
-								Queue: &SQSQueue{
-									Retention:  &duration111Seconds,
-									Delay:      &duration111Seconds,
-									Timeout:    &duration111Seconds,
-									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								},
+								Name:    aws.String("name"),
+								Service: aws.String("svc"),
+								Queue:   newMockSQSQueueOrBool(),
 							},
 						},
 					},
@@ -879,17 +854,12 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					ImageConfig: ImageWithHealthcheck{
 						Image: Image{},
 					},
-					Subscribe: &SubscribeConfig{
+					Subscribe: SubscribeConfig{
 						Topics: []TopicSubscription{
 							{
-								Name:    "name",
-								Service: "svc",
-								Queue: &SQSQueue{
-									Retention:  &duration111Seconds,
-									Delay:      &duration111Seconds,
-									Timeout:    &duration111Seconds,
-									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								},
+								Name:    aws.String("name"),
+								Service: aws.String("svc"),
+								Queue:   newMockSQSQueueOrBool(),
 							},
 						},
 					},
@@ -907,17 +877,12 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(WorkerServiceType),
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
-					Subscribe: &SubscribeConfig{
+					Subscribe: SubscribeConfig{
 						Topics: []TopicSubscription{
 							{
-								Name:    "name",
-								Service: "svc",
-								Queue: &SQSQueue{
-									Retention:  &duration111Seconds,
-									Delay:      &duration111Seconds,
-									Timeout:    &duration111Seconds,
-									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								},
+								Name:    aws.String("name"),
+								Service: aws.String("svc"),
+								Queue:   newMockSQSQueueOrBool(),
 							},
 						},
 					},
@@ -935,17 +900,12 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(WorkerServiceType),
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
-					Subscribe: &SubscribeConfig{
+					Subscribe: SubscribeConfig{
 						Topics: []TopicSubscription{
 							{
-								Name:    "name",
-								Service: "svc",
-								Queue: &SQSQueue{
-									Retention:  &duration111Seconds,
-									Delay:      &duration111Seconds,
-									Timeout:    &duration111Seconds,
-									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								},
+								Name:    aws.String("name"),
+								Service: aws.String("svc"),
+								Queue:   newMockSQSQueueOrBool(),
 							},
 						},
 					},
@@ -966,17 +926,12 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					ImageConfig: ImageWithHealthcheck{
 						Image: Image{},
 					},
-					Subscribe: &SubscribeConfig{
+					Subscribe: SubscribeConfig{
 						Topics: []TopicSubscription{
 							{
-								Name:    "name",
-								Service: "svc",
-								Queue: &SQSQueue{
-									Retention:  &duration111Seconds,
-									Delay:      &duration111Seconds,
-									Timeout:    &duration111Seconds,
-									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								},
+								Name:    aws.String("name"),
+								Service: aws.String("svc"),
+								Queue:   newMockSQSQueueOrBool(),
 							},
 						},
 					},
@@ -994,13 +949,8 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(WorkerServiceType),
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
-					Subscribe: &SubscribeConfig{
-						Queue: &SQSQueue{
-							Retention:  &duration111Seconds,
-							Delay:      &duration111Seconds,
-							Timeout:    &duration111Seconds,
-							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						},
+					Subscribe: SubscribeConfig{
+						Queue: newMockSQSQueue(),
 					},
 				},
 			},
@@ -1016,13 +966,8 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Type: aws.String(WorkerServiceType),
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
-					Subscribe: &SubscribeConfig{
-						Queue: &SQSQueue{
-							Retention:  &duration111Seconds,
-							Delay:      &duration111Seconds,
-							Timeout:    &duration111Seconds,
-							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						},
+					Subscribe: SubscribeConfig{
+						Queue: newMockSQSQueue(),
 					},
 				},
 			},
@@ -1041,13 +986,8 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					ImageConfig: ImageWithHealthcheck{
 						Image: Image{},
 					},
-					Subscribe: &SubscribeConfig{
-						Queue: &SQSQueue{
-							Retention:  &duration111Seconds,
-							Delay:      &duration111Seconds,
-							Timeout:    &duration111Seconds,
-							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						},
+					Subscribe: SubscribeConfig{
+						Queue: newMockSQSQueue(),
 					},
 				},
 			},
@@ -1070,6 +1010,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 
 func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 	mockRange := IntRangeBand("1-10")
+	mockPerc := Percentage(80)
 	testCases := map[string]struct {
 		svcCount Count
 		envCount Count
@@ -1079,8 +1020,8 @@ func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 		"empty env advanced count override": {
 			svcCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{Value: &mockRange},
-					CPU:   aws.Int(80),
+					Range: Range{Value: &mockRange},
+					CPU:   &mockPerc,
 				},
 			},
 			envCount: Count{},
@@ -1089,8 +1030,8 @@ func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{Value: &mockRange},
-								CPU:   aws.Int(80),
+								Range: Range{Value: &mockRange},
+								CPU:   &mockPerc,
 							},
 						},
 					},
@@ -1130,7 +1071,7 @@ func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 		"with range overriden by spot count": {
 			svcCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{Value: &mockRange},
+					Range: Range{Value: &mockRange},
 				},
 			},
 			envCount: Count{
@@ -1153,12 +1094,12 @@ func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 		"with range overriden by range config": {
 			svcCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{Value: &mockRange},
+					Range: Range{Value: &mockRange},
 				},
 			},
 			envCount: Count{
 				AdvancedCount: AdvancedCount{
-					Range: &Range{
+					Range: Range{
 						RangeConfig: RangeConfig{
 							Min: aws.Int(2),
 							Max: aws.Int(8),
@@ -1171,7 +1112,7 @@ func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 					TaskConfig: TaskConfig{
 						Count: Count{
 							AdvancedCount: AdvancedCount{
-								Range: &Range{
+								Range: Range{
 									RangeConfig: RangeConfig{
 										Min: aws.Int(2),
 										Max: aws.Int(8),
@@ -1228,56 +1169,87 @@ func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 	}
 }
 
-func TestWorkerSvc_Subscriptions(t *testing.T) {
+func TestDeadLetterQueue_IsEmpty(t *testing.T) {
 	testCases := map[string]struct {
-		inSubscription SubscribeConfig
-		expected       []TopicSubscription
+		in     DeadLetterQueue
+		wanted bool
 	}{
-		"subscription specified": {
-			inSubscription: SubscribeConfig{
-				Topics: []TopicSubscription{
-					{
-						Name:    "orders",
-						Service: "database",
-					},
-					{
-						Name:    "events",
-						Service: "api",
-					},
-				},
-				Queue: &SQSQueue{
-					Retention: durationPointer(4 * 24 * time.Hour),
-				},
-			},
-			expected: []TopicSubscription{
-				{
-					Name:    "orders",
-					Service: "database",
-				},
-				{
-					Name:    "events",
-					Service: "api",
-				},
-			},
+		"empty dead letter queue": {
+			in:     DeadLetterQueue{},
+			wanted: true,
 		},
-		"no topics": {
-			inSubscription: SubscribeConfig{},
-			expected:       nil,
+		"non empty dead letter queue": {
+			in: DeadLetterQueue{
+				Tries: aws.Uint16(3),
+			},
 		},
 	}
+
 	for name, tc := range testCases {
-		// GIVEN
-		svc := WorkerService{
-			WorkerServiceConfig: WorkerServiceConfig{
-				Subscribe: &tc.inSubscription,
-			},
-		}
 		t.Run(name, func(t *testing.T) {
 			// WHEN
-			actual := svc.Subscriptions()
+			got := tc.in.IsEmpty()
 
 			// THEN
-			require.Equal(t, tc.expected, actual)
+			require.Equal(t, tc.wanted, got)
+		})
+	}
+}
+
+func TestSQSQueueOrBool_UnmarshalYAML(t *testing.T) {
+	testCases := map[string]struct {
+		inContent []byte
+
+		wantedStruct SQSQueueOrBool
+		wantedError  error
+	}{
+		"with boolean": {
+			inContent: []byte(`queue: true`),
+
+			wantedStruct: SQSQueueOrBool{
+				Enabled: aws.Bool(true),
+			},
+		},
+		"with advanced case": {
+			inContent: []byte(`queue:
+  retention: 5s
+  delay: 1m
+  timeout: 5m
+  dead_letter:
+    tries: 10`),
+
+			wantedStruct: SQSQueueOrBool{
+				Advanced: SQSQueue{
+					Retention: durationp(5 * time.Second),
+					Delay:     durationp(1 * time.Minute),
+					Timeout:   durationp(5 * time.Minute),
+					DeadLetter: DeadLetterQueue{
+						Tries: uint16P(10),
+					},
+				},
+			},
+		},
+		"invalid type": {
+			inContent: []byte(`queue: 10`),
+
+			wantedError: errUnmarshalQueueOpts,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			var sc TopicSubscription
+			err := yaml.Unmarshal(tc.inContent, &sc)
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+				// check memberwise dereferenced pointer equality
+				require.Equal(t, tc.wantedStruct.Enabled, sc.Queue.Enabled)
+				require.Equal(t, tc.wantedStruct.Advanced.DeadLetter, sc.Queue.Advanced.DeadLetter)
+				require.Equal(t, tc.wantedStruct.Advanced.Delay, sc.Queue.Advanced.Delay)
+				require.Equal(t, tc.wantedStruct.Advanced.Retention, sc.Queue.Advanced.Retention)
+				require.Equal(t, tc.wantedStruct.Advanced.Timeout, sc.Queue.Advanced.Timeout)
+			}
 		})
 	}
 }
