@@ -5,6 +5,7 @@ package manifest
 
 import (
 	"errors"
+	"fmt"
 	"path/filepath"
 	"testing"
 
@@ -13,6 +14,36 @@ import (
 	"gopkg.in/yaml.v3"
 )
 
+func TestImage_UnmarshalYAML(t *testing.T) {
+	testCases := map[string]struct {
+		inContent []byte
+
+		wantedError error
+	}{
+		"error if both build and location are set": {
+			inContent: []byte(`build: mockBuild
+location: mockLocation`),
+			wantedError: fmt.Errorf(`must specify one of "build" and "location"`),
+		},
+		"success": {
+			inContent: []byte(`location: mockLocation`),
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			i := Image{}
+			err := yaml.Unmarshal(tc.inContent, &i)
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, "mockLocation", aws.StringValue(i.Location))
+			}
+		})
+	}
+}
+
 func TestEntryPointOverride_UnmarshalYAML(t *testing.T) {
 	testCases := map[string]struct {
 		inContent []byte
@@ -47,7 +78,7 @@ func TestEntryPointOverride_UnmarshalYAML(t *testing.T) {
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
 			e := ImageOverride{
-				EntryPoint: &EntryPointOverride{
+				EntryPoint: EntryPointOverride{
 					String: aws.String("wrong"),
 				},
 			}
@@ -138,7 +169,7 @@ func TestCommandOverride_UnmarshalYAML(t *testing.T) {
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
 			e := ImageOverride{
-				Command: &CommandOverride{
+				Command: CommandOverride{
 					String: aws.String("wrong"),
 				},
 			}
@@ -287,6 +318,7 @@ func TestBuildArgs_UnmarshalYAML(t *testing.T) {
 }
 
 func TestPlatformArgsOrString_UnmarshalYAML(t *testing.T) {
+	mockPlatformStr := PlatformString("linux/amd64")
 	testCases := map[string]struct {
 		inContent []byte
 
@@ -300,38 +332,11 @@ func TestPlatformArgsOrString_UnmarshalYAML(t *testing.T) {
 
 			wantedError: errors.New("yaml: line 2: mapping values are not allowed in this context"),
 		},
-		"returns error if platform string invalid": {
-			inContent: []byte(`platform: linus/mad64`),
-
-			wantedError: errors.New("validate platform: platform linus/mad64 is invalid; the valid platform is: linux/amd64"),
-		},
-		"returns error if only args.os specified": {
-			inContent: []byte(`platform:
-  osfamily: linux`),
-			wantedError: errors.New("fields 'osfamily' and 'architecture' must either both be specified or both be empty."),
-		},
-		"returns error if only args.arch specified": {
-			inContent: []byte(`platform:
-  architecture: amd64`),
-			wantedError: errors.New("fields 'osfamily' and 'architecture' must either both be specified or both be empty."),
-		},
-		"returns error if args.os invalid": {
-			inContent: []byte(`platform:
-  osfamily: OSFamilia
-  architecture: amd64`),
-			wantedError: errors.New("validate OS: OS OSFamilia is invalid; the valid operating system is: linux"),
-		},
-		"returns error if args.arch invalid": {
-			inContent: []byte(`platform:
-  osfamily: linux
-  architecture: abc123`),
-			wantedError: errors.New("validate arch: architecture abc123 is invalid; the valid architecture is: amd64"),
-		},
 		"platform string": {
 			inContent: []byte(`platform: linux/amd64`),
 
 			wantedStruct: PlatformArgsOrString{
-				PlatformString: aws.String("linux/amd64"),
+				PlatformString: &mockPlatformStr,
 			},
 		},
 		"both os/arch specified with valid values": {
@@ -355,15 +360,7 @@ func TestPlatformArgsOrString_UnmarshalYAML(t *testing.T) {
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			p := TaskConfig{
-				Platform: &PlatformArgsOrString{
-					PlatformString: nil,
-					PlatformArgs: PlatformArgs{
-						OSFamily: nil,
-						Arch:     nil,
-					},
-				},
-			}
+			p := TaskConfig{}
 			err := yaml.Unmarshal(tc.inContent, &p)
 			if tc.wantedError != nil {
 				require.EqualError(t, err, tc.wantedError.Error())
@@ -549,6 +546,35 @@ func TestBuildConfig(t *testing.T) {
 	}
 }
 
+func TestLogging_IsEmpty(t *testing.T) {
+	testCases := map[string]struct {
+		in     Logging
+		wanted bool
+	}{
+		"empty logging": {
+			in:     Logging{},
+			wanted: true,
+		},
+		"non empty logging": {
+			in: Logging{
+				SecretOptions: map[string]string{
+					"secret1": "value1",
+				},
+			},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// WHEN
+			got := tc.in.IsEmpty()
+
+			// THEN
+			require.Equal(t, tc.wanted, got)
+		})
+	}
+}
+
 func TestLogging_LogImage(t *testing.T) {
 	testCases := map[string]struct {
 		inputImage  *string
@@ -605,6 +631,34 @@ func TestLogging_GetEnableMetadata(t *testing.T) {
 	}
 }
 
+func TestNetworkConfig_IsEmpty(t *testing.T) {
+	testCases := map[string]struct {
+		in     NetworkConfig
+		wanted bool
+	}{
+		"empty network config": {
+			in:     NetworkConfig{},
+			wanted: true,
+		},
+		"non empty network config": {
+			in: NetworkConfig{
+				VPC: vpcConfig{
+					SecurityGroups: []string{"group"},
+				},
+			},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// WHEN
+			got := tc.in.IsEmpty()
+
+			// THEN
+			require.Equal(t, tc.wanted, got)
+		})
+	}
+}
+
 func TestNetworkConfig_UnmarshalYAML(t *testing.T) {
 	testCases := map[string]struct {
 		data string
@@ -618,19 +672,11 @@ network:
   vpc:
 `,
 			wantedConfig: &NetworkConfig{
-				VPC: &vpcConfig{
-					Placement: stringP(PublicSubnetPlacement),
+				VPC: vpcConfig{
+					Placement: &PublicSubnetPlacement,
 				},
 			},
 		},
-		"returns error if placement option is invalid": {
-			data: `
-network:
-  vpc:
-    placement: 'tartarus'
-`,
-			wantedErr: errors.New(`field 'network.vpc.placement' is 'tartarus' must be one of []string{"public", "private"}`),
-		},
 		"unmarshals successfully for public placement with security groups": {
 			data: `
 network:
@@ -641,8 +687,8 @@ network:
     - 'sg-4567'
 `,
 			wantedConfig: &NetworkConfig{
-				VPC: &vpcConfig{
-					Placement:      stringP(PublicSubnetPlacement),
+				VPC: vpcConfig{
+					Placement:      &PublicSubnetPlacement,
 					SecurityGroups: []string{"sg-1234", "sg-4567"},
 				},
 			},
@@ -734,22 +780,8 @@ func TestUnmarshalPublish(t *testing.T) {
 		wantedErr     error
 	}{
 		"Valid publish yaml": {
-			inContent: `topics:
-  - name: tests
-    allowed_workers:
-      - hello
-`,
-			wantedPublish: PublishConfig{
-				Topics: []Topic{
-					{
-						Name:           aws.String("tests"),
-						AllowedWorkers: []string{"hello"},
-					},
-				},
-			},
-		},
-		"Empty workers don't appear in topic": {
-			inContent: `topics:
+			inContent: `
+topics:
   - name: tests
 `,
 			wantedPublish: PublishConfig{
@@ -761,13 +793,10 @@ func TestUnmarshalPublish(t *testing.T) {
 			},
 		},
 		"Error when unmarshalable": {
-			inContent: `topics:
-   - name: tests
-    allowed_workers:
-      - hello
-  - name: orders
+			inContent: `
+topics: abc
 `,
-			wantedErr: errors.New("yaml: line 1: did not find expected '-' indicator"),
+			wantedErr: errors.New("yaml: unmarshal errors:\n  line 2: cannot unmarshal !!str `abc` into []manifest.Topic"),
 		},
 	}
 
