@@ -13,7 +13,6 @@ import (
 	"github.com/google/uuid"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/ecs"
 )
 
 // Constants for template paths.
@@ -104,6 +103,7 @@ type SidecarOpts struct {
 	DependsOn    map[string]string
 	EntryPoint   []string
 	Command      []string
+	HealthCheck  *ContainerHealthCheck
 }
 
 // StorageOpts holds data structures for rendering Volumes and Mount Points
@@ -190,6 +190,15 @@ type AdvancedCount struct {
 	Cps         []*CapacityProviderStrategy
 }
 
+// ContainerHealthCheck holds configuration for container health check.
+type ContainerHealthCheck struct {
+	Command     []string
+	Interval    *int64
+	Retries     *int64
+	StartPeriod *int64
+	Timeout     *int64
+}
+
 // CapacityProviderStrategy holds the configuration needed for a
 // CapacityProviderStrategyItem on a Service
 type CapacityProviderStrategy struct {
@@ -206,6 +215,12 @@ type AutoscalingOpts struct {
 	Memory       *float64
 	Requests     *float64
 	ResponseTime *float64
+	QueueDelay   *AutoscalingQueueDelayOpts
+}
+
+// AutoscalingQueueDelayOpts holds configuration to scale SQS queues.
+type AutoscalingQueueDelayOpts struct {
+	AcceptableBacklogPerTask int
 }
 
 // ExecuteCommandOpts holds configuration that's needed for ECS Execute Command.
@@ -224,8 +239,7 @@ type PublishOpts struct {
 
 // Topic holds information needed to render a SNSTopic in a container definition.
 type Topic struct {
-	Name           *string
-	AllowedWorkers []string
+	Name *string
 
 	Region    string
 	Partition string
@@ -310,15 +324,18 @@ type WorkloadOpts struct {
 	ServiceDiscoveryEndpoint string
 
 	// Additional options for service templates.
-	WorkloadType         string
-	HealthCheck          *ecs.HealthCheck
-	HTTPHealthCheck      HTTPHealthCheckOpts
-	DeregistrationDelay  *int64
-	AllowedSourceIps     []string
-	RulePriorityLambda   string
-	DesiredCountLambda   string
-	EnvControllerLambda  string
-	CredentialsParameter string
+	WorkloadType        string
+	HealthCheck         *ContainerHealthCheck
+	HTTPHealthCheck     HTTPHealthCheckOpts
+	DeregistrationDelay *int64
+	AllowedSourceIps    []string
+
+	// Lambda functions.
+	RulePriorityLambda             string
+	DesiredCountLambda             string
+	EnvControllerLambda            string
+	CredentialsParameter           string
+	BacklogPerTaskCalculatorLambda string
 
 	// Additional options for job templates.
 	ScheduleExpression string
@@ -331,6 +348,7 @@ type WorkloadOpts struct {
 // ParseRequestDrivenWebServiceInput holds data that can be provided to enable features for a request-driven web service stack.
 type ParseRequestDrivenWebServiceInput struct {
 	Variables           map[string]string
+	StartCommand        *string
 	Tags                map[string]string        // Used by App Runner workloads to tag App Runner service resources
 	NestedStack         *WorkloadNestedStackOpts // Outputs from nested stacks such as the addons stack.
 	EnableHealthCheck   bool
@@ -423,7 +441,7 @@ func withSvcParsingFuncs() ParseOption {
 			"toSnakeCase":         ToSnakeCaseFunc,
 			"hasSecrets":          hasSecrets,
 			"fmtSlice":            FmtSliceFunc,
-			"quoteSlice":          QuotePSliceFunc,
+			"quoteSlice":          QuoteSliceFunc,
 			"randomUUID":          randomUUIDFunc,
 			"jsonMountPoints":     generateMountPointJSON,
 			"jsonSNSTopics":       generateSNSJSON,
